@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Modules::AdminDynamicFieldMultiselect;
@@ -568,7 +568,7 @@ sub _ShowScreen {
         if ( $DynamicfieldNamesList{$OrderNumber} && $OrderNumber ne $Param{FieldOrder} ) {
             $OrderNamesList{$OrderNumber} = $OrderNumber . ' - '
                 . $CurrentlyText
-                . $DynamicfieldNamesList{$OrderNumber}
+                . $DynamicfieldNamesList{$OrderNumber};
         }
     }
 
@@ -628,7 +628,7 @@ sub _ShowScreen {
 
                 # set the error class
                 $KeyError     = 'ServerError';
-                $KeyErrorStrg = 'This field is required.'
+                $KeyErrorStrg = 'This field is required.';
             }
 
             # check for errors on original value (duplicate)
@@ -640,7 +640,7 @@ sub _ShowScreen {
 
                 # set the error class
                 $KeyError     = 'ServerError';
-                $KeyErrorStrg = 'This field value is duplicated.'
+                $KeyErrorStrg = 'This field value is duplicated.';
             }
 
             # check for error on value
@@ -679,7 +679,7 @@ sub _ShowScreen {
     for my $ValueItem ( sort keys %PossibleValues ) {
         next POSSIBLEVALUE if !defined $ValueItem;
         next POSSIBLEVALUE if !defined $PossibleValues{$ValueItem};
-        $DefaultValuesList{$ValueItem} = $PossibleValues{$ValueItem}
+        $DefaultValuesList{$ValueItem} = $PossibleValues{$ValueItem};
     }
 
     my $DefaultValue = ( defined $Param{DefaultValue} ? $Param{DefaultValue} : '' );
