@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Modules::AdminRoleUser;
@@ -74,9 +74,10 @@ sub Run {
 
         # get user list, with the full name in the value
         my %UserData = $Self->{UserObject}->UserList( Valid => 1 );
+        USERID:
         for my $UserID ( sort keys %UserData ) {
             my $Name = $Self->{UserObject}->UserName( UserID => $UserID );
-            next if !$Name;
+            next USERID if !$Name;
             $UserData{$UserID} .= " ($Name)";
         }
 
@@ -120,10 +121,11 @@ sub Run {
         # add or remove user from roles
         for my $UserID ( sort keys %UserData ) {
             my $Active = 0;
+            MEMBER_OF_ROLE:
             for my $MemberOfRole (@IDs) {
-                next if $MemberOfRole ne $UserID;
+                next MEMBER_OF_ROLE if $MemberOfRole ne $UserID;
                 $Active = 1;
-                last;
+                last MEMBER_OF_ROLE;
             }
             $Self->{GroupObject}->GroupUserRoleMemberAdd(
                 UID    => $UserID,
@@ -156,10 +158,11 @@ sub Run {
         # add or remove user from roles
         for my $RoleID ( sort keys %RoleData ) {
             my $Active = 0;
+            ROLE_OF_MEMBER:
             for my $RoleOfMember (@IDs) {
-                next if $RoleOfMember ne $RoleID;
+                next ROLE_OF_MEMBER if $RoleOfMember ne $RoleID;
                 $Active = 1;
-                last;
+                last ROLE_OF_MEMBER;
             }
             $Self->{GroupObject}->GroupUserRoleMemberAdd(
                 UID    => $ID,
@@ -253,9 +256,10 @@ sub _Overview {
     my %UserData = $Self->{UserObject}->UserList( Valid => 1 );
 
     # get user name
+    USERID:
     for my $UserID ( sort keys %UserData ) {
         my $Name = $Self->{UserObject}->UserName( UserID => $UserID );
-        next if !$Name;
+        next USERID if !$Name;
         $UserData{$UserID} .= " ($Name)";
     }
     for my $UserID ( sort { uc( $UserData{$a} ) cmp uc( $UserData{$b} ) } keys %UserData ) {
