@@ -1,10 +1,9 @@
 # --
-# Kernel/Modules/AdminUser.pm - to add/update/delete user and preferences
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Modules::AdminUser;
@@ -82,6 +81,7 @@ sub Run {
             %UserData,
             UserLastRequest => $Self->{TimeObject}->SystemTime(),
             UserType        => 'User',
+            SessionSource   => 'AgentInterface',
         );
 
         # create a new LayoutObject with SessionIDCookie
@@ -188,7 +188,6 @@ sub Run {
             UserLogin => $GetParam{UserLogin},
             UserID    => $GetParam{UserID}
         );
-
         if ($UserLoginExists) {
             $Errors{UserLoginExists} = 1;
             $Errors{'UserLoginInvalid'} = 'ServerError';
@@ -206,8 +205,9 @@ sub Run {
 
             if ($Update) {
                 my %Preferences = %{ $Self->{ConfigObject}->Get('PreferencesGroups') };
+                GROUP:
                 for my $Group ( sort keys %Preferences ) {
-                    next if $Group eq 'Password';
+                    next GROUP if $Group eq 'Password';
 
                     # get user data
                     my %UserData = $Self->{UserObject}->GetUserData(
@@ -266,12 +266,7 @@ sub Run {
             }
         }
         my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Note
-            ? $Self->{LayoutObject}->Notify(
-            Priority => 'Error',
-            Info     => $Note,
-            )
-            : '';
+        $Output .= $Note;
         $Output .= $Self->{LayoutObject}->NavigationBar();
         $Self->_Edit(
             Action    => 'Change',
@@ -348,7 +343,6 @@ sub Run {
 
         # check if a user with this login (username) already exits
         my $UserLoginExists = $Self->{UserObject}->UserLoginExistsCheck( UserLogin => $GetParam{UserLogin} );
-
         if ($UserLoginExists) {
             $Errors{UserLoginExists} = 1;
             $Errors{'UserLoginInvalid'} = 'ServerError';
@@ -368,8 +362,9 @@ sub Run {
 
                 # update preferences
                 my %Preferences = %{ $Self->{ConfigObject}->Get('PreferencesGroups') };
+                GROUP:
                 for my $Group ( sort keys %Preferences ) {
-                    next if $Group eq 'Password';
+                    next GROUP if $Group eq 'Password';
 
                     # get user data
                     my %UserData = $Self->{UserObject}->GetUserData(
@@ -548,11 +543,12 @@ sub _Edit {
             next GROUP if $Preferences{$Group}->{Column} ne $Column;
 
             if ( $Data{ $Preferences{$Group}->{Prio} } ) {
+                COUNT:
                 for ( 1 .. 151 ) {
                     $Preferences{$Group}->{Prio}++;
                     if ( !$Data{ $Preferences{$Group}->{Prio} } ) {
                         $Data{ $Preferences{$Group}->{Prio} } = $Group;
-                        last;
+                        last COUNT;
                     }
                 }
             }
@@ -566,14 +562,15 @@ sub _Edit {
         }
 
         # show each preferences setting
+        PRIO:
         for my $Prio ( sort keys %Data ) {
             my $Group = $Data{$Prio};
             if ( !$Self->{ConfigObject}->{PreferencesGroups}->{$Group} ) {
-                next;
+                next PRIO;
             }
             my %Preference = %{ $Self->{ConfigObject}->{PreferencesGroups}->{$Group} };
             if ( $Group eq 'Password' ) {
-                next;
+                next PRIO;
             }
             my $Module = $Preference{Module} || 'Kernel::Output::HTML::PreferencesGeneric';
 
