@@ -1,10 +1,9 @@
 # --
-# Kernel/Modules/CustomerTicketSearch.pm - Utilities for tickets
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Modules::CustomerTicketSearch;
@@ -525,7 +524,7 @@ sub Run {
 
         # disable output of company tickets if configured
         if ( $Self->{DisableCompanyTickets} ) {
-            $GetParam{CustomerUserLogin} = $Self->{UserID};
+            $GetParam{CustomerUserLoginRaw} = $Self->{UserID};
         }
 
         # perform ticket search
@@ -611,7 +610,12 @@ sub Run {
                     }
                     else
                     {
+                        ARTICLE:
                         for my $Articles (@Article) {
+
+                            # Skip internal articles.
+                            next ARTICLE if $Articles->{ArticleType} =~ /-int/;
+
                             if ( $Articles->{Body} ) {
                                 $Data{ArticleTree}
                                     .= "\n-->||$Articles->{ArticleType}||$Articles->{From}||"
@@ -742,10 +746,9 @@ sub Run {
         elsif ( $GetParam{ResultForm} eq 'Print' ) {
             for my $TicketID (@ViewableTicketIDs) {
 
-                # get first article data
-                my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
+                # Get last customer or any other article if it doesn't exist.
+                my %Article = $Self->_LastCustomerArticle(
                     TicketID      => $TicketID,
-                    Extended      => 1,
                     DynamicFields => 0,
                 );
 
@@ -921,10 +924,9 @@ sub Run {
                     )
                 {
 
-                    # get first article data
-                    my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(
+                    # Get last customer or any other article if it doesn't exist.
+                    my %Article = $Self->_LastCustomerArticle(
                         TicketID      => $TicketID,
-                        Extended      => 1,
                         DynamicFields => 1,
                     );
 
@@ -1303,7 +1305,7 @@ sub Run {
                     if ( IsHashRefWithData($HistoricalValues) ) {
                         for my $Key ( sort keys %{$HistoricalValues} ) {
                             if ( !$Data->{$Key} ) {
-                                $Data->{$Key} = $HistoricalValues->{$Key}
+                                $Data->{$Key} = $HistoricalValues->{$Key};
                             }
                         }
                     }
@@ -1406,13 +1408,13 @@ sub MaskForm {
     if ( $Self->{ConfigObject}->Get('Customer::TicketSearch::AllServices') ) {
         %ServiceList = $Self->{ServiceObject}->ServiceList(
             UserID => $Self->{UserID},
-            ),
+        );
     }
     else {
         %ServiceList = $Self->{ServiceObject}->CustomerUserServiceMemberList(
             CustomerUserLogin => $Self->{UserID},
             Result            => 'HASH',
-            ),
+        );
     }
 
     $Param{ServicesStrg} = $Self->{LayoutObject}->BuildSelection(
@@ -1698,4 +1700,45 @@ sub _StopWordsServerErrorsGet {
     return %StopWordsServerErrors;
 }
 
+sub _LastCustomerArticle {
+    my ( $Self, %Param ) = @_;
+
+    # Get all customer articles.
+    my @Index = $Self->{TicketObject}->ArticleIndex(
+        TicketID   => $Param{TicketID},
+        SenderType => 'customer',
+    );
+
+    # Go over articles in reverse order and return the last external one.
+    if (@Index) {
+        for my $CustomerArticleID ( reverse @Index ) {
+            my %LastCustomerArticle = $Self->{TicketObject}->ArticleGet(
+                ArticleID     => $CustomerArticleID,
+                Extended      => 1,
+                DynamicFields => $Param{DynamicFields},
+            );
+            if ( $LastCustomerArticle{ArticleType} !~ /-int/ ) {
+                return %LastCustomerArticle;
+            }
+        }
+    }
+
+    # If no customer articles were found, return the last external one.
+    @Index = $Self->{TicketObject}->ArticleIndex(
+        TicketID => $Param{TicketID},
+    );
+    for my $ArticleID ( reverse @Index ) {
+        my %LastArticle = $Self->{TicketObject}->ArticleGet(
+            ArticleID     => $ArticleID,
+            Extended      => 1,
+            DynamicFields => $Param{DynamicFields},
+        );
+        if ( $LastArticle{StateType} eq 'merged' || $LastArticle{ArticleType} !~ /-int/ ) {
+            return %LastArticle;
+        }
+    }
+
+    return;
+}
+
 1;
