@@ -1,10 +1,9 @@
 # --
-# Kernel/System/ACL/DB/ACL.pm - ACL DB backend
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::ACL::DB::ACL;
@@ -12,11 +11,18 @@ package Kernel::System::ACL::DB::ACL;
 use strict;
 use warnings;
 
-use Kernel::System::YAML;
-
-use Kernel::System::Cache;
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::System::User;
+
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::Cache',
+    'Kernel::System::DB',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::Time',
+    'Kernel::System::User',
+    'Kernel::System::YAML',
+);
 
 =head1 NAME
 
@@ -34,46 +40,11 @@ ACL DB ACL backend
 
 =item new()
 
-create a ACL object
+create a ACL object. Do not use it directly, instead use:
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::Time;
-    use Kernel::System::DB;
-    use Kernel::System::ACL::DB::ACL;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $TimeObject = Kernel::System::Time->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $ACLObject = Kernel::System::ACL::DB::ACL->new(
-        ConfigObject        => $ConfigObject,
-        EncodeObject        => $EncodeObject,
-        LogObject           => $LogObject,
-        MainObject          => $MainObject,
-        DBObject            => $DBObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $ACLObject = $Kernel::OM->Get('Kernel::System::ACL::DB::ACL');
 
 =cut
 
@@ -84,25 +55,12 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for my $Needed (qw(ConfigObject EncodeObject LogObject TimeObject MainObject DBObject)) {
-        die "Got no $Needed!" if !$Param{$Needed};
-
-        $Self->{$Needed} = $Param{$Needed};
-    }
-
-    # create additional objects
-    $Self->{CacheObject} = Kernel::System::Cache->new( %{$Self} );
-    $Self->{YAMLObject}  = Kernel::System::YAML->new( %{$Self} );
-    $Self->{UserObject}  = Kernel::System::User->new( %{$Self} );
-
     # get the cache TTL (in seconds)
-    $Self->{CacheTTL}
-        = int( $Self->{ConfigObject}->Get('ACL::CacheTTL') || 3600 );
+    $Self->{CacheTTL} = int( $Kernel::OM->Get('Kernel::Config')->Get('ACL::CacheTTL') || 3600 );
 
     # set lower if database is case sensitive
     $Self->{Lower} = '';
-    if ( !$Self->{DBObject}->GetDatabaseFunction('CaseInsensitive') ) {
+    if ( $Kernel::OM->Get('Kernel::System::DB')->GetDatabaseFunction('CaseSensitive') ) {
         $Self->{Lower} = 'LOWER';
     }
 
@@ -138,7 +96,7 @@ sub ACLAdd {
     # check needed stuff
     for my $Key (qw(Name ValidID UserID)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Key!",
             );
@@ -146,6 +104,9 @@ sub ACLAdd {
         }
     }
 
+    # get yaml object
+    my $YAMLObject = $Kernel::OM->Get('Kernel::System::YAML');
+
     # define Description field if not present
     $Param{Description} //= '';
 
@@ -155,33 +116,36 @@ sub ACLAdd {
     if ( $Param{ConfigMatch} ) {
 
         if ( !IsHashRefWithData( $Param{ConfigMatch} ) ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "ConfigMatch needs to be a valid hash with data!",
             );
             return;
         }
 
-        $ConfigMatch = $Self->{YAMLObject}->Dump( Data => $Param{ConfigMatch} );
+        $ConfigMatch = $YAMLObject->Dump( Data => $Param{ConfigMatch} );
         utf8::upgrade($ConfigMatch);
     }
 
     if ( $Param{ConfigChange} ) {
 
         if ( !IsHashRefWithData( $Param{ConfigChange} ) ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "ConfigChange needs to be a valid hash with data!",
             );
             return;
         }
 
-        $ConfigChange = $Self->{YAMLObject}->Dump( Data => $Param{ConfigChange} );
+        $ConfigChange = $YAMLObject->Dump( Data => $Param{ConfigChange} );
         utf8::upgrade($ConfigChange);
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # check if ACL with this name already exists
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL => "
             SELECT id
             FROM acl
@@ -191,20 +155,20 @@ sub ACLAdd {
     );
 
     my $ACLExists;
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Data = $DBObject->FetchrowArray() ) {
         $ACLExists = 1;
     }
 
     if ($ACLExists) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "The Name:$Param{Name} already exists for an ACL!"
         );
         return;
     }
 
-    # sql
-    return if !$Self->{DBObject}->Do(
+    # SQL
+    return if !$DBObject->Do(
         SQL => '
             INSERT INTO acl ( name, comments, description, stop_after_match, config_match,
                 config_change, valid_id, create_time, create_by, change_time, change_by )
@@ -216,24 +180,24 @@ sub ACLAdd {
         ],
     );
 
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL  => 'SELECT id FROM acl WHERE name = ?',
         Bind => [ \$Param{Name} ],
     );
 
     my $ID;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $ID = $Row[0];
     }
 
     return if !$ID;
 
     # delete cache
-    $Self->{CacheObject}->CleanUp(
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
         Type => 'ACLEditor_ACL',
     );
 
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL => '
             INSERT INTO acl_sync ( acl_id, sync_state, create_time, change_time )
             VALUES (?, ?, current_timestamp, current_timestamp)',
@@ -262,7 +226,10 @@ sub ACLDelete {
     # check needed stuff
     for my $Key (qw(ID UserID)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Key!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $Key!"
+            );
             return;
         }
     }
@@ -272,20 +239,24 @@ sub ACLDelete {
         ID     => $Param{ID},
         UserID => 1,
     );
+
     return if !IsHashRefWithData($ACL);
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # delete ACL
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL  => 'DELETE FROM acl WHERE id = ?',
         Bind => [ \$Param{ID} ],
     );
 
     # delete cache
-    $Self->{CacheObject}->CleanUp(
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
         Type => 'ACLEditor_ACL',
     );
 
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL => '
             INSERT INTO acl_sync ( acl_id, sync_state, create_time, change_time )
             VALUES (?, ?, current_timestamp, current_timestamp)',
@@ -329,12 +300,15 @@ sub ACLGet {
 
     # check needed stuff
     if ( !$Param{ID} && !$Param{Name} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need ID or Name!' );
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Need ID or Name!'
+        );
         return;
     }
 
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need UserID!',
         );
@@ -350,15 +324,21 @@ sub ACLGet {
         $CacheKey = 'ACLGet::Name::' . $Param{Name};
     }
 
-    my $Cache = $Self->{CacheObject}->Get(
+    # get cache object
+    my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
+
+    my $Cache = $CacheObject->Get(
         Type => 'ACLEditor_ACL',
         Key  => $CacheKey,
     );
     return $Cache if $Cache;
 
-    # sql
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    # SQL
     if ( $Param{ID} ) {
-        return if !$Self->{DBObject}->Prepare(
+        return if !$DBObject->Prepare(
             SQL => '
                 SELECT id, name, comments, description, stop_after_match, valid_id, config_match,
                     config_change, create_time, change_time, create_by, change_by
@@ -369,7 +349,7 @@ sub ACLGet {
         );
     }
     else {
-        return if !$Self->{DBObject}->Prepare(
+        return if !$DBObject->Prepare(
             SQL => '
                 SELECT id, name, comments, description, stop_after_match, valid_id, config_match,
                     config_change, create_time, change_time, create_by, change_by
@@ -380,18 +360,20 @@ sub ACLGet {
         );
     }
 
-    my %Data;
+    # get yaml object
+    my $YAMLObject = $Kernel::OM->Get('Kernel::System::YAML');
 
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    my %Data;
+    while ( my @Data = $DBObject->FetchrowArray() ) {
 
         my $ConfigMatch = '';
         if ( $Data[6] ) {
-            $ConfigMatch = $Self->{YAMLObject}->Load( Data => $Data[6] );
+            $ConfigMatch = $YAMLObject->Load( Data => $Data[6] );
         }
 
         my $ConfigChange = '';
         if ( $Data[7] ) {
-            $ConfigChange = $Self->{YAMLObject}->Load( Data => $Data[7] );
+            $ConfigChange = $YAMLObject->Load( Data => $Data[7] );
         }
 
         %Data = (
@@ -412,14 +394,17 @@ sub ACLGet {
 
     return if !$Data{ID};
 
+    # get user object
+    my $UserObject = $Kernel::OM->Get('Kernel::System::User');
+
     # convert UserIDs outside of fetchrowArray, otherwise UserLooukup will rise some warnings
-    my $CreateUser = $Self->{UserObject}->UserLookup( UserID => $Data{CreateBy} );
-    my $ChangeUser = $Self->{UserObject}->UserLookup( UserID => $Data{ChangeBy} );
+    my $CreateUser = $UserObject->UserLookup( UserID => $Data{CreateBy} );
+    my $ChangeUser = $UserObject->UserLookup( UserID => $Data{ChangeBy} );
     $Data{CreateBy} = $CreateUser;
     $Data{ChangeBy} = $ChangeUser;
 
     # set cache
-    $Self->{CacheObject}->Set(
+    $CacheObject->Set(
         Type  => 'ACLEditor_ACL',
         Key   => $CacheKey,
         Value => \%Data,
@@ -455,7 +440,10 @@ sub ACLUpdate {
     # check needed stuff
     for my $Key (qw(ID Name ValidID UserID)) {
         if ( !$Param{$Key} ) {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $Key!" );
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $Key!"
+            );
             return;
         }
     }
@@ -469,7 +457,7 @@ sub ACLUpdate {
     for my $Key (qw(ConfigMatch ConfigChange)) {
 
         if ( $Param{$Key} && !IsHashRefWithData( $Param{$Key} ) ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "$Key needs to be a valid hash with data!",
             );
@@ -477,33 +465,39 @@ sub ACLUpdate {
         }
     }
 
+    # get yaml object
+    my $YAMLObject = $Kernel::OM->Get('Kernel::System::YAML');
+
     if ( $Param{ConfigMatch} && IsHashRefWithData( $Param{ConfigMatch} ) ) {
-        $ConfigMatch = $Self->{YAMLObject}->Dump( Data => $Param{ConfigMatch} );
+        $ConfigMatch = $YAMLObject->Dump( Data => $Param{ConfigMatch} );
         utf8::upgrade($ConfigMatch);
     }
 
     if ( $Param{ConfigChange} && IsHashRefWithData( $Param{ConfigChange} ) ) {
-        $ConfigChange = $Self->{YAMLObject}->Dump( Data => $Param{ConfigChange} );
+        $ConfigChange = $YAMLObject->Dump( Data => $Param{ConfigChange} );
         utf8::upgrade($ConfigChange);
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # check if Name already exists
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL => "
             SELECT id FROM acl
             WHERE $Self->{Lower}(name) = $Self->{Lower}(?)
             AND id != ?",
-        Bind => [ \$Param{Name}, \$Param{ID} ],
+        Bind  => [ \$Param{Name}, \$Param{ID} ],
         LIMIT => 1,
     );
 
     my $ACLExists;
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Data = $DBObject->FetchrowArray() ) {
         $ACLExists = 1;
     }
 
     if ($ACLExists) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "The Name:$Param{Name} already exists for a different ACL!",
         );
@@ -511,7 +505,7 @@ sub ACLUpdate {
     }
 
     # check if need to update db
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL => '
             SELECT name, comments, description, stop_after_match, valid_id, config_match,
                 config_change
@@ -528,7 +522,7 @@ sub ACLUpdate {
     my $CurrentValidID;
     my $CurrentConfigMatch;
     my $CurrentConfigChange;
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Data = $DBObject->FetchrowArray() ) {
         $CurrentName           = $Data[0];
         $CurrentComment        = $Data[1];
         $CurrentDescription    = $Data[2] || '';
@@ -552,8 +546,8 @@ sub ACLUpdate {
         return 1;
     }
 
-    # sql
-    return if !$Self->{DBObject}->Do(
+    # SQL
+    return if !$DBObject->Do(
         SQL => '
             UPDATE acl
             SET name = ?, comments = ?, description = ?, stop_after_match = ?, valid_id = ?,
@@ -567,11 +561,11 @@ sub ACLUpdate {
     );
 
     # delete cache
-    $Self->{CacheObject}->CleanUp(
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
         Type => 'ACLEditor_ACL',
     );
 
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL => '
             INSERT INTO acl_sync ( acl_id, sync_state, create_time, change_time )
             VALUES (?, ?, current_timestamp, current_timestamp)',
@@ -602,7 +596,7 @@ sub ACLList {
 
     # check needed
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Need UserID!"
         );
@@ -617,34 +611,40 @@ sub ACLList {
         $ValidIDsStrg = join ',', @{ $Param{ValidIDs} };
     }
 
+    # get cache object
+    my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
+
     # check cache
     my $CacheKey = 'ACLList::ValidIDs::' . $ValidIDsStrg;
-    my $Cache    = $Self->{CacheObject}->Get(
+    my $Cache    = $CacheObject->Get(
         Type => 'ACLEditor_ACL',
         Key  => $CacheKey,
     );
     return $Cache if ref $Cache;
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     my $SQL = '
             SELECT id, name
             FROM acl ';
 
     if ( $ValidIDsStrg ne 'ALL' ) {
 
-        my $ValidIDsStrgDB = join ',', map $Self->{DBObject}->Quote( $_, 'Integer' ),
+        my $ValidIDsStrgDB = join ',', map { $DBObject->Quote( $_, 'Integer' ) }
             @{ $Param{ValidIDs} };
 
         $SQL .= "WHERE valid_id IN ($ValidIDsStrgDB)";
     }
 
-    return if !$Self->{DBObject}->Prepare( SQL => $SQL );
+    return if !$DBObject->Prepare( SQL => $SQL );
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $Data{ $Row[0] } = $Row[1];
     }
 
     # set cache
-    $Self->{CacheObject}->Set(
+    $CacheObject->Set(
         Type  => 'ACLEditor_ACL',
         Key   => $CacheKey,
         Value => \%Data,
@@ -697,7 +697,7 @@ sub ACLListGet {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need UserID!',
         );
@@ -712,34 +712,39 @@ sub ACLListGet {
         $ValidIDsStrg = join ',', @{ $Param{ValidIDs} };
     }
 
+    # get cache object
+    my $CacheObject = $Kernel::OM->Get('Kernel::System::Cache');
+
     # check cache
     my $CacheKey = 'ACLListGet::ValidIDs::' . $ValidIDsStrg;
-
-    my $Cache = $Self->{CacheObject}->Get(
+    my $Cache    = $CacheObject->Get(
         Type => 'ACLEditor_ACL',
         Key  => $CacheKey,
     );
     return $Cache if $Cache;
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     my $SQL = '
             SELECT id
             FROM acl ';
+
     if ( $ValidIDsStrg ne 'ALL' ) {
 
-        my $ValidIDsStrgDB
-            = join ',', map $Self->{DBObject}->Quote( $_, 'Integer' ), @{ $Param{ValidIDs} };
+        my $ValidIDsStrgDB = join ',', map { $DBObject->Quote( $_, 'Integer' ) } @{ $Param{ValidIDs} };
 
         $SQL .= "WHERE valid_id IN ($ValidIDsStrgDB)";
     }
     $SQL .= 'ORDER BY id';
 
-    # sql
-    return if !$Self->{DBObject}->Prepare(
+    # SQL
+    return if !$DBObject->Prepare(
         SQL => $SQL,
     );
 
     my @ACLIDs;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         push @ACLIDs, $Row[0];
     }
 
@@ -754,7 +759,7 @@ sub ACLListGet {
     }
 
     # set cache
-    $Self->{CacheObject}->Set(
+    $CacheObject->Set(
         Type  => 'ACLEditor_ACL',
         Key   => $CacheKey,
         Value => \@Data,
@@ -772,20 +777,23 @@ Check if there are unsynchronized ACLs
 
     Returns:
 
-    $SyncCount = 0 || Number of ALCs that need to be synched
+    $SyncCount = 0 || Number of ALCs that need to be synced
 =cut
 
 sub ACLsNeedSync {
     my ( $Self, %Param ) = @_;
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     my $SQL = '
         SELECT COUNT(*)
         FROM acl_sync';
 
-    return if !$Self->{DBObject}->Prepare( SQL => $SQL );
+    return if !$DBObject->Prepare( SQL => $SQL );
 
     my $NeedSync = 0;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $NeedSync = $Row[0];
     }
 
@@ -801,7 +809,7 @@ Reset synchronization information for ACLs.
 sub ACLsNeedSyncReset {
     my ( $Self, %Param ) = @_;
 
-    return if !$Self->{DBObject}->Do( SQL => 'DELETE FROM acl_sync' );
+    return if !$Kernel::OM->Get('Kernel::System::DB')->Do( SQL => 'DELETE FROM acl_sync' );
 
     return 1;
 }
@@ -826,7 +834,7 @@ sub ACLDump {
 
     # check needed stuff
     if ( !$Param{UserID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need UserID!',
         );
@@ -839,7 +847,7 @@ sub ACLDump {
 
     if ( $Param{ResultType} eq 'FILE' ) {
         if ( !$Param{Location} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => 'Need Location for ResultType \'FILE\'!',
             );
@@ -863,15 +871,17 @@ sub ACLDump {
         my $Properties;
         my $PropertiesDatabase;
         if ( IsHashRefWithData( $ACLData->{ConfigMatch} ) ) {
-            $Properties             = $ACLData->{ConfigMatch}->{Properties},
-                $PropertiesDatabase = $ACLData->{ConfigMatch}->{PropertiesDatabase},
+            $Properties         = $ACLData->{ConfigMatch}->{Properties};
+            $PropertiesDatabase = $ACLData->{ConfigMatch}->{PropertiesDatabase};
         }
 
         my $Possible;
+        my $PossibleAdd;
         my $PossibleNot;
         if ( IsHashRefWithData( $ACLData->{ConfigChange} ) ) {
-            $Possible        = $ACLData->{ConfigChange}->{Possible},
-                $PossibleNot = $ACLData->{ConfigChange}->{PossibleNot},
+            $Possible    = $ACLData->{ConfigChange}->{Possible};
+            $PossibleAdd = $ACLData->{ConfigChange}->{PossibleAdd};
+            $PossibleNot = $ACLData->{ConfigChange}->{PossibleNot};
         }
 
         $ACLDump{ $ACLData->{Name} } = {
@@ -885,13 +895,14 @@ sub ACLDump {
                 Properties         => $Properties                || {},
                 PropertiesDatabase => $PropertiesDatabase        || {},
                 Possible           => $Possible                  || {},
+                PossibleAdd        => $PossibleAdd               || {},
                 PossibleNot        => $PossibleNot               || {},
             },
         };
     }
 
     # delete cache
-    $Self->{CacheObject}->CleanUp(
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
         Type => 'ACLEditor_ACL',
     );
 
@@ -911,16 +922,15 @@ sub ACLDump {
     }
 
     # get current time for the file comment
-    my $CurrentTime = $Self->{TimeObject}->CurrentTimestamp();
+    my $CurrentTime = $Kernel::OM->Get('Kernel::System::Time')->CurrentTimestamp();
 
     # get user data of the current user to use for the file comment
-    $Self->{UserObject} = Kernel::System::User->new( %{$Self} );
-    my %User = $Self->{UserObject}->GetUserData(
+    my %User = $Kernel::OM->Get('Kernel::System::User')->GetUserData(
         UserID => $Param{UserID},
     );
 
     # remove home from location path to show in file comment
-    my $Home     = $Self->{ConfigObject}->Get('Home');
+    my $Home     = $Kernel::OM->Get('Kernel::Config')->Get('Home');
     my $Location = $Param{Location};
     $Location =~ s{$Home\/}{}xmsg;
 
@@ -931,6 +941,7 @@ sub ACLDump {
 package Kernel::Config::Files::ZZZACL;
 use strict;
 use warnings;
+no warnings 'redefine';
 use utf8;
 sub Load {
     my ($File, $Self) = @_;
@@ -944,7 +955,7 @@ EOF
 
     $Output = $FileStart . $Output . $FileEnd;
 
-    my $FileLocation = $Self->{MainObject}->FileWrite(
+    my $FileLocation = $Kernel::OM->Get('Kernel::System::Main')->FileWrite(
         Location => $Param{Location},
         Content  => \$Output,
         Mode     => 'utf8',
@@ -954,6 +965,193 @@ EOF
     return $FileLocation;
 }
 
+=item ACLImport()
+
+import an ACL YAML file/content
+
+    my $ACLImport = $ACLObject->ACLImport(
+        Content                   => $YAMLContent, # mandatory, YAML format
+        OverwriteExistingEntities => 0,            # 0 || 1
+        UserID                    => 1,            # mandatory
+    );
+
+Returns:
+
+    $ACLImport = {
+        Success      => 1,                         # 1 if success or undef if operation could not
+                                                   #    be performed
+        Message     => 'The Message to show.',     # error message
+        AddedACLs   => 'ACL1, ACL2',               # list of ACLs correctly added
+        UpdatedACLs => 'ACL3, ACL4',               # list of ACLs correctly updated
+        ACLErrors   => 'ACL5',                     # list of ACLs that could not be added or updated
+    };
+
+=cut
+
+sub ACLImport {
+    my ( $Self, %Param ) = @_;
+
+    for my $Needed (qw(Content UserID)) {
+
+        # check needed stuff
+        if ( !$Param{$Needed} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "Need $Needed!",
+            );
+            return {
+                Success => 0,
+                Message => "$Needed is missing can not continue.",
+            };
+        }
+    }
+
+    my $ACLData = $Kernel::OM->Get('Kernel::System::YAML')->Load( Data => $Param{Content} );
+
+    if ( ref $ACLData ne 'ARRAY' ) {
+        return {
+            Success => 0,
+            Message =>
+                "Couldn't read ACL configuration file. Please make sure the file is valid.",
+        };
+    }
+
+    my @UpdatedACLs;
+    my @AddedACLs;
+    my @ACLErrors;
+
+    ACL:
+    for my $ACL ( @{$ACLData} ) {
+
+        next ACL if !$ACL;
+        next ACL if ref $ACL ne 'HASH';
+
+        $ACL = $Self->_ACLMigrateFrom33(
+            ACL    => $ACL,
+            UserID => $Param{UserID},
+        );
+
+        my @ExistingACLs = @{ $Self->ACLListGet( UserID => $Param{UserID} ) || [] };
+        @ExistingACLs = grep { $_->{Name} eq $ACL->{Name} } @ExistingACLs;
+
+        if ( $Param{OverwriteExistingEntities} && $ExistingACLs[0] ) {
+            my $Success = $Self->ACLUpdate(
+                %{ $ExistingACLs[0] },
+                Name           => $ACL->{Name},
+                Comment        => $ACL->{Comment},
+                Description    => $ACL->{Description} || '',
+                StopAfterMatch => $ACL->{StopAfterMatch} || 0,
+                ConfigMatch    => $ACL->{ConfigMatch} || undef,
+                ConfigChange   => $ACL->{ConfigChange} || undef,
+                ValidID        => $ACL->{ValidID} || 1,
+                UserID         => $Param{UserID},
+            );
+
+            if ($Success) {
+                push @UpdatedACLs, $ACL->{Name};
+            }
+            else {
+                push @ACLErrors, $ACL->{Name};
+            }
+
+        }
+        else {
+
+            # now add the ACL
+            my $Success = $Self->ACLAdd(
+                Name           => $ACL->{Name},
+                Comment        => $ACL->{Comment},
+                Description    => $ACL->{Description} || '',
+                ConfigMatch    => $ACL->{ConfigMatch} || undef,
+                ConfigChange   => $ACL->{ConfigChange} || undef,
+                StopAfterMatch => $ACL->{StopAfterMatch},
+                ValidID        => $ACL->{ValidID} || 1,
+                UserID         => $Param{UserID},
+            );
+
+            if ($Success) {
+                push @AddedACLs, $ACL->{Name};
+            }
+            else {
+                push @ACLErrors, $ACL->{Name};
+            }
+        }
+    }
+
+    return {
+        Success     => 1,
+        AddedACLs   => join( ', ', @AddedACLs ) || '',
+        UpdatedACLs => join( ', ', @UpdatedACLs ) || '',
+        ACLErrors   => join( ', ', @ACLErrors ) || '',
+    };
+}
+
+=begin Internal:
+
+=cut
+
+=item _ACLItemOutput()
+
+converts an ACL structure to perl code suitable to be saved on a perl file.
+
+    my $Output = $ACLObject->_ACLItemOutput (
+        Key => 'some ACL name',
+        Value => {
+            Properties => {
+                Ticket => {
+                    Priority => [ 'some priority' ],
+                    Queue    => [ 'some queue' ],
+                },
+            },
+            PropertiesDatabase => { },                      # similar to Properties or empty hash ref
+            Possible => {
+                Ticket => {
+                Queue => [ 'some other queue' ],
+            },
+            PossibleNot => { },                             # similar to Possible or empty hash ref
+            PossibleAdd => { },                             # similar to Possible or empty hash ref
+            StopAfterMatch => 0,                            # 0 or 1
+        },
+        Comment    => 'some comment',
+        CreateTime => '2014-06-03 19:03:57',
+        ChangeTime => '2014-06-03 19:51:17',
+        CreateBy   => 'some user login',
+        ChangeBy   => 'some user login',
+    );
+
+returns:
+
+    $Output = '
+        # Created: 2014-06-03 19:03:57 (some user login)
+        # Changed: 2014-06-03 19:51:17 (some user login)
+        # Comment: some comment
+        $Self->{TicketAcl}->{"100-Example-ACL"} = {
+          \\'Possible\\' => {
+            \\'Ticket\\' => {
+              \\'Queue\\' => [
+                \\'some other queue\\'
+              ]
+            }
+          },
+          \\'PossibleAdd\\' => {},
+          \\'PossibleNot\\' => {},
+          \\'Properties\\' => {
+            \\'Ticket\\' => {
+              \\'Priority\\' => [
+                \\'some priority\\'
+              ],
+              \\'Queue\\' => [
+                \\'some queue\\'
+              ]
+            }
+          },
+          \\'PropertiesDatabase\\' => {},
+          \\'StopAfterMatch\\' => 0
+        };
+        ';
+
+=cut
+
 sub _ACLItemOutput {
     my ( $Self, %Param ) = @_;
 
@@ -964,7 +1162,7 @@ sub _ACLItemOutput {
         $Output .= "# Comment: $Param{Comment}\n";
     }
 
-    $Output .= $Self->{MainObject}->Dump(
+    $Output .= $Kernel::OM->Get('Kernel::System::Main')->Dump(
         $Param{Value},
     );
 
@@ -972,25 +1170,111 @@ sub _ACLItemOutput {
     $Output =~ s{\[empty\]}{}xmsg;
 
     my $Name = $Param{Key};
-    $Name =~ s{\"}{\\"}xmsg;
-    my $Key = '$Self->{TicketAcl}->{"' . $Name . '"}';
+    $Name =~ s{\'}{\\'}xmsg;
+    my $Key = '$Self->{TicketAcl}->{\'' . $Name . '\'}';
 
     $Output =~ s{\$VAR1}{$Key}mxs;
 
     return $Output . "\n";
 }
 
+=item _ACLMigrateFrom33()
+
+Updates ACLs structure my changing the Possible->Action hash ref to a PossibleNot->Action array ref
+with just the elements that where set to 0 in the original ACL:
+
+    my $ACL = $ACLObject->_ACLMigrateFrom33 (
+        $ACL => {
+            ID          => 123,
+            Name        => 'some name',
+            Description => '',
+            Comment     => 'Comment',
+            ConfigMatch => {
+                Properties' => {},
+            },
+            ConfigChange => {
+                Possible => {}
+                    Action => {
+                        AgentTicketPhone   => 1,
+                        AgentTicketPrint   => 0,
+                        AgentTicketZoom    => 1,
+                        AgentTicketCLose   => 0,
+                        AgentTicketCompose => 0,
+                    },
+                },
+                PossibleNot => {},
+            },
+            StopAfterMatch => 1,
+            ValidID        => 1,
+            CreateTime     => '2013-09-20 11:56:05',
+            CreateBy       => 'root@localhost',
+            ChangeTime     => '2014-06-16 11:31:55',
+            ChangeBy       => 'root@localhost',
+        };
+        UserID => 123,
+    )
+
+Returns:
+
+        $ACL = {
+            ID          => 123,
+            Name        => 'some name',
+            Description => '',
+            Comment     => 'Comment',
+            ConfigMatch => {
+                Properties' => {},
+            },
+            ConfigChange => {
+                Possible => {},
+                PossibleNot => {
+                    Action => [
+                        'AgentTicketCLose',
+                        'AgentTicketCompose',
+                        'AgentTicketPrint'
+                    ],
+                },
+            }
+            StopAfterMatch => 1,
+            ValidID        => 1,
+            CreateBy       => 'root@localhost',
+            CreateTime     => '2013-09-20 11:56:05',
+            ChangeTime     => '2014-06-16 11:31:55',
+            ChangeBy       => 'root@localhost',
+        };
+
+=cut
+
+sub _ACLMigrateFrom33 {
+    my ( $Self, %Param ) = @_;
+
+    my $ACL = $Param{ACL};
+
+    return $ACL if !ref $ACL->{ConfigChange};
+    return $ACL if !$ACL->{ConfigChange}->{Possible}->{Action};
+    return $ACL if ref $ACL->{ConfigChange}->{Possible}->{Action} ne 'HASH';
+
+    # convert old hash into an array using only the keys set to 0, and skip those that are set
+    # to 1, set them as PossibleNot and delete the Possible->Action section form the ACL.
+    my @NewAction = grep { $ACL->{ConfigChange}->{Possible}->{Action}->{$_} == 0 }
+        sort keys %{ $ACL->{ConfigChange}->{Possible}->{Action} };
+
+    delete $ACL->{ConfigChange}->{Possible}->{Action};
+    $ACL->{ConfigChange}->{PossibleNot}->{Action} = \@NewAction;
+
+    return $ACL;
+}
+
 1;
 
 =back
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
 
