@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::ProcessManagement::TransitionAction::TicketCreate;
@@ -185,7 +185,7 @@ sub Run {
         )
     {
         if ( defined $Param{Config}->{$Attribute} ) {
-            $TicketParam{$Attribute} = $Param{Config}->{$Attribute}
+            $TicketParam{$Attribute} = $Param{Config}->{$Attribute};
         }
     }
 
@@ -293,7 +293,7 @@ sub Run {
         )
     {
         if ( defined $Param{Config}->{$Attribute} ) {
-            $ArticleParam{$Attribute} = $Param{Config}->{$Attribute}
+            $ArticleParam{$Attribute} = $Param{Config}->{$Attribute};
         }
     }
 
@@ -460,10 +460,10 @@ sub Run {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
