@@ -1,12 +1,9 @@
 # --
-# Kernel/System/Stats/Dynamic/Ticket.pm - all advice functions
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: Ticket.pm,v 1.38 2012-02-28 10:38:01 jp Exp $
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::Stats::Dynamic::Ticket;
@@ -14,17 +11,25 @@ package Kernel::System::Stats::Dynamic::Ticket;
 use strict;
 use warnings;
 
-use Kernel::System::Queue;
-use Kernel::System::Service;
-use Kernel::System::SLA;
-use Kernel::System::Ticket;
-use Kernel::System::Type;
-use Kernel::System::DynamicField;
-use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.38 $) [1];
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::System::DB',
+    'Kernel::System::DynamicField',
+    'Kernel::System::DynamicField::Backend',
+    'Kernel::System::Lock',
+    'Kernel::System::Log',
+    'Kernel::System::Priority',
+    'Kernel::System::Queue',
+    'Kernel::System::Service',
+    'Kernel::System::SLA',
+    'Kernel::System::State',
+    'Kernel::System::Ticket',
+    'Kernel::System::Time',
+    'Kernel::System::Type',
+    'Kernel::System::User',
+);
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -33,27 +38,8 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for my $Object (
-        qw(DBObject ConfigObject LogObject UserObject TimeObject MainObject EncodeObject)
-        )
-    {
-        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
-    }
-    $Self->{QueueObject}        = Kernel::System::Queue->new( %{$Self} );
-    $Self->{TicketObject}       = Kernel::System::Ticket->new( %{$Self} );
-    $Self->{StateObject}        = Kernel::System::State->new( %{$Self} );
-    $Self->{PriorityObject}     = Kernel::System::Priority->new( %{$Self} );
-    $Self->{LockObject}         = Kernel::System::Lock->new( %{$Self} );
-    $Self->{CustomerUser}       = Kernel::System::CustomerUser->new( %{$Self} );
-    $Self->{ServiceObject}      = Kernel::System::Service->new( %{$Self} );
-    $Self->{SLAObject}          = Kernel::System::SLA->new( %{$Self} );
-    $Self->{TypeObject}         = Kernel::System::Type->new( %{$Self} );
-    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new(%Param);
-    $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new(%Param);
-
     # get the dynamic fields for ticket object
-    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+    $Self->{DynamicField} = $Kernel::OM->Get('Kernel::System::DynamicField')->DynamicFieldListGet(
         Valid      => 1,
         ObjectType => ['Ticket'],
     );
@@ -67,40 +53,71 @@ sub GetObjectName {
     return 'TicketAccumulation';
 }
 
+sub GetObjectBehaviours {
+    my ( $Self, %Param ) = @_;
+
+    my %Behaviours = (
+        ProvidesDashboardWidget => 1,
+    );
+
+    return %Behaviours;
+}
+
 sub GetObjectAttributes {
     my ( $Self, %Param ) = @_;
 
-    # get user list
-    my %UserList = $Self->{UserObject}->UserList(
-        Type  => 'Long',
-        Valid => 0,
+    # get needed objects
+    my $ConfigObject   = $Kernel::OM->Get('Kernel::Config');
+    my $UserObject     = $Kernel::OM->Get('Kernel::System::User');
+    my $QueueObject    = $Kernel::OM->Get('Kernel::System::Queue');
+    my $TicketObject   = $Kernel::OM->Get('Kernel::System::Ticket');
+    my $StateObject    = $Kernel::OM->Get('Kernel::System::State');
+    my $PriorityObject = $Kernel::OM->Get('Kernel::System::Priority');
+    my $LockObject     = $Kernel::OM->Get('Kernel::System::Lock');
+    my $DBObject       = $Kernel::OM->Get('Kernel::System::DB');
+
+    my $ValidAgent = 0;
+    if (
+        defined $ConfigObject->Get('Stats::UseInvalidAgentInStats')
+        && ( $ConfigObject->Get('Stats::UseInvalidAgentInStats') == 0 )
+        )
+    {
+        $ValidAgent = 1;
+    }
+
+    # Get user list without the out of office message, because of the caching in the statistics
+    #   and not meaningful with a date selection.
+    my %UserList = $UserObject->UserList(
+        Type          => 'Long',
+        Valid         => $ValidAgent,
+        NoOutOfOffice => 1,
     );
 
     # get state list
-    my %StateList = $Self->{StateObject}->StateList(
+    my %StateList = $StateObject->StateList(
         UserID => 1,
     );
 
     # get state type list
-    my %StateTypeList = $Self->{StateObject}->StateTypeList(
+    my %StateTypeList = $StateObject->StateTypeList(
         UserID => 1,
     );
 
     # get queue list
-    my %QueueList = $Self->{QueueObject}->GetAllQueues();
+    my %QueueList = $QueueObject->GetAllQueues();
 
     # get priority list
-    my %PriorityList = $Self->{PriorityObject}->PriorityList(
+    my %PriorityList = $PriorityObject->PriorityList(
         UserID => 1,
     );
 
     # get lock list
-    my %LockList = $Self->{LockObject}->LockList(
+    my %LockList = $LockObject->LockList(
         UserID => 1,
     );
 
     # get current time to fix bug#3830
-    my $TimeStamp = $Self->{TimeObject}->CurrentTimestamp();
+    my $TimeStamp = $Kernel::OM->Get('Kernel::System::Time')->CurrentTimestamp();
     my ($Date) = split /\s+/, $TimeStamp;
     my $Today = sprintf "%s 23:59:59", $Date;
 
@@ -113,6 +130,7 @@ sub GetObjectAttributes {
             Element          => 'QueueIDs',
             Block            => 'MultiSelectField',
             Translation      => 0,
+            TreeView         => 1,
             Values           => \%QueueList,
         },
         {
@@ -150,6 +168,7 @@ sub GetObjectAttributes {
             Element          => 'CreatedQueueIDs',
             Block            => 'MultiSelectField',
             Translation      => 0,
+            TreeView         => 1,
             Values           => \%QueueList,
         },
         {
@@ -249,6 +268,34 @@ sub GetObjectAttributes {
                 TimeStop  => 'TicketCreateTimeOlderDate',
             },
         },
+        {
+            Name             => 'Last changed times',
+            UseAsXvalue      => 1,
+            UseAsValueSeries => 1,
+            UseAsRestriction => 1,
+            Element          => 'LastChangeTime',
+            TimePeriodFormat => 'DateInputFormat',      # 'DateInputFormatLong',
+            Block            => 'Time',
+            TimeStop         => $Today,
+            Values           => {
+                TimeStart => 'TicketLastChangeTimeNewerDate',
+                TimeStop  => 'TicketLastChangeTimeOlderDate',
+            },
+        },
+        {
+            Name             => 'Change times',
+            UseAsXvalue      => 1,
+            UseAsValueSeries => 1,
+            UseAsRestriction => 1,
+            Element          => 'ChangeTime',
+            TimePeriodFormat => 'DateInputFormat',    # 'DateInputFormatLong',
+            Block            => 'Time',
+            TimeStop         => $Today,
+            Values           => {
+                TimeStart => 'TicketChangeTimeNewerDate',
+                TimeStop  => 'TicketChangeTimeOlderDate',
+            },
+        },
         {
             Name             => 'Close Time',
             UseAsXvalue      => 1,
@@ -321,15 +368,16 @@ sub GetObjectAttributes {
         },
     );
 
-    if ( $Self->{ConfigObject}->Get('Ticket::Service') ) {
+    if ( $ConfigObject->Get('Ticket::Service') ) {
 
         # get service list
-        my %Service = $Self->{ServiceObject}->ServiceList(
-            UserID => 1,
+        my %Service = $Kernel::OM->Get('Kernel::System::Service')->ServiceList(
+            KeepChildren => $ConfigObject->Get('Ticket::Service::KeepChildren'),
+            UserID       => 1,
         );
 
         # get sla list
-        my %SLA = $Self->{SLAObject}->SLAList(
+        my %SLA = $Kernel::OM->Get('Kernel::System::SLA')->SLAList(
             UserID => 1,
         );
 
@@ -342,6 +390,7 @@ sub GetObjectAttributes {
                 Element          => 'ServiceIDs',
                 Block            => 'MultiSelectField',
                 Translation      => 0,
+                TreeView         => 1,
                 Values           => \%Service,
             },
             {
@@ -359,10 +408,10 @@ sub GetObjectAttributes {
         unshift @ObjectAttributes, @ObjectAttributeAdd;
     }
 
-    if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
+    if ( $ConfigObject->Get('Ticket::Type') ) {
 
         # get ticket type list
-        my %Type = $Self->{TypeObject}->TypeList(
+        my %Type = $Kernel::OM->Get('Kernel::System::Type')->TypeList(
             UserID => 1,
         );
 
@@ -380,7 +429,7 @@ sub GetObjectAttributes {
         unshift @ObjectAttributes, \%ObjectAttribute1;
     }
 
-    if ( $Self->{ConfigObject}->Get('Stats::UseAgentElementInStats') ) {
+    if ( $ConfigObject->Get('Stats::UseAgentElementInStats') ) {
 
         my @ObjectAttributeAdd = (
             {
@@ -418,17 +467,17 @@ sub GetObjectAttributes {
         push @ObjectAttributes, @ObjectAttributeAdd;
     }
 
-    if ( $Self->{ConfigObject}->Get('Stats::CustomerIDAsMultiSelect') ) {
+    if ( $ConfigObject->Get('Stats::CustomerIDAsMultiSelect') ) {
 
         # Get CustomerID
         # (This way also can be the solution for the CustomerUserID)
-        $Self->{DBObject}->Prepare(
+        $DBObject->Prepare(
             SQL => "SELECT DISTINCT customer_id FROM ticket",
         );
 
         # fetch the result
         my %CustomerID;
-        while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        while ( my @Row = $DBObject->FetchrowArray() ) {
             if ( $Row[0] ) {
                 $CustomerID{ $Row[0] } = $Row[0];
             }
@@ -460,35 +509,97 @@ sub GetObjectAttributes {
         push @ObjectAttributes, \%ObjectAttribute;
     }
 
+    if ( $ConfigObject->Get('Ticket::ArchiveSystem') ) {
+
+        my %ObjectAttribute = (
+            Name             => 'Archive Search',
+            UseAsXvalue      => 0,
+            UseAsValueSeries => 0,
+            UseAsRestriction => 1,
+            Element          => 'SearchInArchive',
+            Block            => 'SelectField',
+            Translation      => 1,
+            Values           => {
+                ArchivedTickets    => 'Archived tickets',
+                NotArchivedTickets => 'Unarchived tickets',
+                AllTickets         => 'All tickets',
+            },
+        );
+
+        push @ObjectAttributes, \%ObjectAttribute;
+    }
+
+    # get dynamic field backend object
+    my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
+
     # cycle trough the activated Dynamic Fields for this screen
     DYNAMICFIELD:
     for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
         next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
 
+        # skip all fields not designed to be supported by statistics
+        my $IsStatsCondition = $DynamicFieldBackendObject->HasBehavior(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            Behavior           => 'IsStatsCondition',
+        );
+
+        next DYNAMICFIELD if !$IsStatsCondition;
+
         my $PossibleValuesFilter;
 
-        # set possible values filter from ACLs
-        my $ACL = $Self->{TicketObject}->TicketAcl(
-            Action        => 'AgentStats',
-            Type          => 'DynamicField_' . $DynamicFieldConfig->{Name},
-            ReturnType    => 'Ticket',
-            ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
-            Data          => $DynamicFieldConfig->{Config}->{PossibleValues} || {},
-            UserID        => 1,
+        my $IsACLReducible = $DynamicFieldBackendObject->HasBehavior(
+            DynamicFieldConfig => $DynamicFieldConfig,
+            Behavior           => 'IsACLReducible',
         );
-        if ($ACL) {
-            my %Filter = $Self->{TicketObject}->TicketAclData();
-            $PossibleValuesFilter = \%Filter;
+
+        if ($IsACLReducible) {
+
+            # get PossibleValues
+            my $PossibleValues = $DynamicFieldBackendObject->PossibleValuesGet(
+                DynamicFieldConfig => $DynamicFieldConfig,
+            );
+
+            # convert possible values key => value to key => key for ACLs using a Hash slice
+            my %AclData = %{ $PossibleValues || {} };
+            @AclData{ keys %AclData } = keys %AclData;
+
+            # set possible values filter from ACLs
+            my $ACL = $TicketObject->TicketAcl(
+                Action        => 'AgentStats',
+                Type          => 'DynamicField_' . $DynamicFieldConfig->{Name},
+                ReturnType    => 'Ticket',
+                ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
+                Data          => \%AclData || {},
+                UserID        => 1,
+            );
+            if ($ACL) {
+                my %Filter = $TicketObject->TicketAclData();
+
+                # convert Filer key => key back to key => value using map
+                %{$PossibleValuesFilter} = map { $_ => $PossibleValues->{$_} } keys %Filter;
+            }
         }
 
         # get field html
-        my $DynamicFieldStatsParameter = $Self->{BackendObject}->StatsFieldParameterBuild(
+        my $DynamicFieldStatsParameter = $DynamicFieldBackendObject->StatsFieldParameterBuild(
             DynamicFieldConfig   => $DynamicFieldConfig,
             PossibleValuesFilter => $PossibleValuesFilter,
         );
 
         if ( IsHashRefWithData($DynamicFieldStatsParameter) ) {
-            if ( IsHashRefWithData( $DynamicFieldStatsParameter->{Values} ) ) {
+
+            # backward compatibility
+            if ( !$DynamicFieldStatsParameter->{Block} ) {
+                $DynamicFieldStatsParameter->{Block} = 'InputField';
+                if ( IsHashRefWithData( $DynamicFieldStatsParameter->{Values} ) ) {
+                    $DynamicFieldStatsParameter->{Block} = 'MultiSelectField';
+                }
+            }
+
+            if ( $DynamicFieldStatsParameter->{Block} eq 'Time' ) {
+
+                # create object attributes (date/time fields)
+                my $TimePeriodFormat = $DynamicFieldStatsParameter->{TimePeriodFormat} || 'DateInputFormatLong';
 
                 my %ObjectAttribute = (
                     Name             => $DynamicFieldStatsParameter->{Name},
@@ -496,20 +607,47 @@ sub GetObjectAttributes {
                     UseAsValueSeries => 1,
                     UseAsRestriction => 1,
                     Element          => $DynamicFieldStatsParameter->{Element},
-                    Block            => 'MultiSelectField',
+                    TimePeriodFormat => $TimePeriodFormat,
+                    Block            => $DynamicFieldStatsParameter->{Block},
+                    TimePeriodFormat => $TimePeriodFormat,
+                    Values           => {
+                        TimeStart =>
+                            $DynamicFieldStatsParameter->{Element}
+                            . '_GreaterThanEquals',
+                        TimeStop =>
+                            $DynamicFieldStatsParameter->{Element}
+                            . '_SmallerThanEquals',
+                    },
+                );
+                push @ObjectAttributes, \%ObjectAttribute;
+            }
+            elsif ( $DynamicFieldStatsParameter->{Block} eq 'MultiSelectField' ) {
+
+                # create object attributes (multiple values)
+                my %ObjectAttribute = (
+                    Name             => $DynamicFieldStatsParameter->{Name},
+                    UseAsXvalue      => 1,
+                    UseAsValueSeries => 1,
+                    UseAsRestriction => 1,
+                    Element          => $DynamicFieldStatsParameter->{Element},
+                    Block            => $DynamicFieldStatsParameter->{Block},
                     Values           => $DynamicFieldStatsParameter->{Values},
-                    Translation      => 0,
+                    Translation      => $DynamicFieldStatsParameter->{TranslatableValues} || 0,
+                    IsDynamicField   => 1,
+                    ShowAsTree       => $DynamicFieldConfig->{Config}->{TreeView} || 0,
                 );
                 push @ObjectAttributes, \%ObjectAttribute;
             }
             else {
+
+                # create object attributes (text fields)
                 my %ObjectAttribute = (
                     Name             => $DynamicFieldStatsParameter->{Name},
                     UseAsXvalue      => 0,
                     UseAsValueSeries => 0,
                     UseAsRestriction => 1,
                     Element          => $DynamicFieldStatsParameter->{Element},
-                    Block            => 'InputField',
+                    Block            => $DynamicFieldStatsParameter->{Block},
                 );
                 push @ObjectAttributes, \%ObjectAttribute;
             }
@@ -522,16 +660,30 @@ sub GetObjectAttributes {
 sub GetStatElement {
     my ( $Self, %Param ) = @_;
 
-    #
+    # get dynamic field backend object
+    my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
+    my $DBObject                  = $Kernel::OM->Get('Kernel::System::DB');
+    my $ConfigObject              = $Kernel::OM->Get('Kernel::Config');
+
     # escape search attributes for ticket search
-    #
     my %AttributesToEscape = (
         'CustomerID' => 1,
         'Title'      => 1,
     );
 
-    for my $ParameterName ( keys %Param ) {
-        if ( $ParameterName =~ m{\A DynamicField_ ( [a-zA-Z\d]+ ) \z}xms ) {
+    # Map the CustomerID search parameter to CustomerIDRaw search parameter for the
+    #   exact search match, if the 'Stats::CustomerIDAsMultiSelect' is active.
+    if ( $ConfigObject->Get('Stats::CustomerIDAsMultiSelect') ) {
+        $Param{CustomerIDRaw} = $Param{CustomerID};
+    }
+
+    for my $ParameterName ( sort keys %Param ) {
+        if (
+            $ParameterName =~ m{ \A DynamicField_ ( [a-zA-Z\d]+ ) (?: _ ( [a-zA-Z\d]+ ) )? \z }xms
+            )
+        {
+            my $FieldName = $1;
+            my $Operator  = $2;
 
             # loop over the dynamic fields configured
             DYNAMICFIELD:
@@ -539,39 +691,70 @@ sub GetStatElement {
                 next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
                 next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
 
-                # skip all fields that does not match with current field name ($1)
+                # skip all fields that do not match with current field name
                 # without the 'DynamicField_' prefix
-                next DYNAMICFIELD if $DynamicFieldConfig->{Name} ne $1;
+                next DYNAMICFIELD if $DynamicFieldConfig->{Name} ne $FieldName;
+
+                # skip all fields not designed to be supported by statistics
+                my $IsStatsCondition = $DynamicFieldBackendObject->HasBehavior(
+                    DynamicFieldConfig => $DynamicFieldConfig,
+                    Behavior           => 'IsStatsCondition',
+                );
+
+                next DYNAMICFIELD if !$IsStatsCondition;
 
                 # get new search parameter
-                my $DynamicFieldStatsSearchParameter
-                    = $Self->{BackendObject}->CommonSearchFieldParameterBuild(
+                my $DynamicFieldStatsSearchParameter = $DynamicFieldBackendObject->StatsSearchFieldParameterBuild(
                     DynamicFieldConfig => $DynamicFieldConfig,
                     Value              => $Param{$ParameterName},
-                    );
+                    Operator           => $Operator,
+                );
 
                 # add new search parameter
-                $Param{$ParameterName} = $DynamicFieldStatsSearchParameter;
+                if ( !IsHashRefWithData( $Param{"DynamicField_$FieldName"} ) ) {
+                    $Param{"DynamicField_$FieldName"} =
+                        $DynamicFieldStatsSearchParameter;
+                }
+
+                # extend search parameter
+                elsif ( IsHashRefWithData($DynamicFieldStatsSearchParameter) ) {
+                    $Param{"DynamicField_$FieldName"} = {
+                        %{ $Param{"DynamicField_$FieldName"} },
+                        %{$DynamicFieldStatsSearchParameter},
+                    };
+                }
             }
         }
         elsif ( $AttributesToEscape{$ParameterName} ) {
             if ( ref $Param{$ParameterName} ) {
                 if ( ref $Param{$ParameterName} eq 'ARRAY' ) {
                     $Param{$ParameterName} = [
-                        map { $Self->{DBObject}->QueryStringEscape( QueryString => $_ ) }
+                        map { $DBObject->QueryStringEscape( QueryString => $_ ) }
                             @{ $Param{$ParameterName} }
                     ];
                 }
             }
             else {
-                $Param{$ParameterName}
-                    = $Self->{DBObject}->QueryStringEscape( QueryString => $Param{$ParameterName} );
+                $Param{$ParameterName} = $DBObject->QueryStringEscape( QueryString => $Param{$ParameterName} );
             }
         }
     }
 
+    if ( $ConfigObject->Get('Ticket::ArchiveSystem') ) {
+        $Param{SearchInArchive} ||= '';
+        if ( $Param{SearchInArchive} eq 'AllTickets' ) {
+            $Param{ArchiveFlags} = [ 'y', 'n' ];
+        }
+        elsif ( $Param{SearchInArchive} eq 'ArchivedTickets' ) {
+            $Param{ArchiveFlags} = ['y'];
+        }
+        else {
+            $Param{ArchiveFlags} = ['n'];
+        }
+    }
+
     # search tickets
-    return $Self->{TicketObject}->TicketSearch(
+    return $Kernel::OM->Get('Kernel::System::Ticket')->TicketSearch(
         UserID     => 1,
         Result     => 'COUNT',
         Permission => 'ro',
@@ -583,6 +766,12 @@ sub GetStatElement {
 sub ExportWrapper {
     my ( $Self, %Param ) = @_;
 
+    # get needed objects
+    my $UserObject     = $Kernel::OM->Get('Kernel::System::User');
+    my $QueueObject    = $Kernel::OM->Get('Kernel::System::Queue');
+    my $StateObject    = $Kernel::OM->Get('Kernel::System::State');
+    my $PriorityObject = $Kernel::OM->Get('Kernel::System::Priority');
+
     # wrap ids to used spelling
     for my $Use (qw(UseAsValueSeries UseAsRestriction UseAsXvalue)) {
         ELEMENT:
@@ -595,11 +784,11 @@ sub ExportWrapper {
                 ID:
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
-                    $ID->{Content} = $Self->{QueueObject}->QueueLookup( QueueID => $ID->{Content} );
+                    $ID->{Content} = $QueueObject->QueueLookup( QueueID => $ID->{Content} );
                 }
             }
             elsif ( $ElementName eq 'StateIDs' || $ElementName eq 'CreatedStateIDs' ) {
-                my %StateList = $Self->{StateObject}->StateList( UserID => 1 );
+                my %StateList = $StateObject->StateList( UserID => 1 );
                 ID:
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
@@ -607,7 +796,7 @@ sub ExportWrapper {
                 }
             }
             elsif ( $ElementName eq 'PriorityIDs' || $ElementName eq 'CreatedPriorityIDs' ) {
-                my %PriorityList = $Self->{PriorityObject}->PriorityList( UserID => 1 );
+                my %PriorityList = $PriorityObject->PriorityList( UserID => 1 );
                 ID:
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
@@ -615,7 +804,7 @@ sub ExportWrapper {
                 }
             }
             elsif (
-                $ElementName    eq 'OwnerIDs'
+                $ElementName eq 'OwnerIDs'
                 || $ElementName eq 'CreatedUserIDs'
                 || $ElementName eq 'ResponsibleIDs'
                 )
@@ -623,19 +812,26 @@ sub ExportWrapper {
                 ID:
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
-                    $ID->{Content} = $Self->{UserObject}->UserLookup( UserID => $ID->{Content} );
+                    $ID->{Content} = $UserObject->UserLookup( UserID => $ID->{Content} );
                 }
             }
 
-            # Locks and statustype don't have to wrap because they are never different
+            # locks and statustype don't have to wrap because they are never different
         }
     }
+
     return \%Param;
 }
 
 sub ImportWrapper {
     my ( $Self, %Param ) = @_;
 
+    # get needed objects
+    my $UserObject     = $Kernel::OM->Get('Kernel::System::User');
+    my $QueueObject    = $Kernel::OM->Get('Kernel::System::Queue');
+    my $StateObject    = $Kernel::OM->Get('Kernel::System::State');
+    my $PriorityObject = $Kernel::OM->Get('Kernel::System::Priority');
+
     # wrap used spelling to ids
     for my $Use (qw(UseAsValueSeries UseAsRestriction UseAsXvalue)) {
         ELEMENT:
@@ -648,12 +844,11 @@ sub ImportWrapper {
                 ID:
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
-                    if ( $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} ) ) {
-                        $ID->{Content}
-                            = $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} );
+                    if ( $QueueObject->QueueLookup( Queue => $ID->{Content} ) ) {
+                        $ID->{Content} = $QueueObject->QueueLookup( Queue => $ID->{Content} );
                     }
                     else {
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'error',
                             Message  => "Import: Can' find the queue $ID->{Content}!"
                         );
@@ -666,7 +861,7 @@ sub ImportWrapper {
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
 
-                    my %State = $Self->{StateObject}->StateGet(
+                    my %State = $StateObject->StateGet(
                         Name  => $ID->{Content},
                         Cache => 1,
                     );
@@ -674,7 +869,7 @@ sub ImportWrapper {
                         $ID->{Content} = $State{ID};
                     }
                     else {
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'error',
                             Message  => "Import: Can' find state $ID->{Content}!"
                         );
@@ -683,9 +878,9 @@ sub ImportWrapper {
                 }
             }
             elsif ( $ElementName eq 'PriorityIDs' || $ElementName eq 'CreatedPriorityIDs' ) {
-                my %PriorityList = $Self->{PriorityObject}->PriorityList( UserID => 1 );
+                my %PriorityList = $PriorityObject->PriorityList( UserID => 1 );
                 my %PriorityIDs;
-                for my $Key ( keys %PriorityList ) {
+                for my $Key ( sort keys %PriorityList ) {
                     $PriorityIDs{ $PriorityList{$Key} } = $Key;
                 }
                 ID:
@@ -696,7 +891,7 @@ sub ImportWrapper {
                         $ID->{Content} = $PriorityIDs{ $ID->{Content} };
                     }
                     else {
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'error',
                             Message  => "Import: Can' find priority $ID->{Content}!"
                         );
@@ -705,7 +900,7 @@ sub ImportWrapper {
                 }
             }
             elsif (
-                $ElementName    eq 'OwnerIDs'
+                $ElementName eq 'OwnerIDs'
                 || $ElementName eq 'CreatedUserIDs'
                 || $ElementName eq 'ResponsibleIDs'
                 )
@@ -714,13 +909,13 @@ sub ImportWrapper {
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
 
-                    if ( $Self->{UserObject}->UserLookup( UserLogin => $ID->{Content} ) ) {
-                        $ID->{Content} = $Self->{UserObject}->UserLookup(
+                    if ( $UserObject->UserLookup( UserLogin => $ID->{Content} ) ) {
+                        $ID->{Content} = $UserObject->UserLookup(
                             UserLogin => $ID->{Content}
                         );
                     }
                     else {
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'error',
                             Message  => "Import: Can' find user $ID->{Content}!"
                         );
@@ -729,7 +924,7 @@ sub ImportWrapper {
                 }
             }
 
-            # Locks and statustype don't have to wrap because they are never different
+            # locks and status type don't have to wrap because they are never different
         }
     }
     return \%Param;
