@@ -1,10 +1,9 @@
 # --
-# Kernel/System/SupportDataCollector.pm - system data collector
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::SupportDataCollector;
@@ -115,38 +114,55 @@ sub Collect {
         return %{$Cache} if ref $Cache eq 'HASH';
     }
 
-    # Data must be collected in a web request context to be able to collect webserver data.
-    #   If called from CLI, make a web request to collect the data.
+    # Data must be collected in a web request context to be able to collect web server data.
+    #   If called from CLI, make a web request to collect the data, but if the data couldn't
+    #   be collected the function runs normal.
     if ( !$ENV{GATEWAY_INTERFACE} ) {
-        return $Self->CollectByWebRequest( WebTimeout => $Param{WebTimeout} );
+
+        my %ResultWebRequest = $Self->CollectByWebRequest(%Param);
+
+        return %ResultWebRequest if $ResultWebRequest{Success};
     }
 
-    # Look for all plugins in the FS
+    # Get the disabled plugins from the config to generate a lookup hash, which can be used to skip these plugins.
+    my $PluginDisabled = $Kernel::OM->Get('Kernel::Config')->Get('SupportDataCollector::DisablePlugins') || [];
+    my %LookupPluginDisabled = map { $_ => 1 } @{$PluginDisabled};
+
+    # Get the identifier filter blacklist from the config to generate a lookup hash, which can be used
+    # to filter these identifier.
+    my $IdentifierFilterBlacklist
+        = $Kernel::OM->Get('Kernel::Config')->Get('SupportDataCollector::IdentifierFilterBlacklist') || [];
+    my %LookupIdentifierFilterBlacklist = map { $_ => 1 } @{$IdentifierFilterBlacklist};
+
+    # Look for all plug-ins in the FS.
     my @PluginFiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
         Directory => dirname(__FILE__) . "/SupportDataCollector/Plugin",
         Filter    => "*.pm",
         Recursive => 1,
     );
 
-    # Look for all asynchronous plugins in the FS
+    # Look for all asynchronous plug-ins in the FS.
     my @PluginAsynchronousFiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
         Directory => dirname(__FILE__) . "/SupportDataCollector/PluginAsynchronous",
         Filter    => "*.pm",
         Recursive => 1,
     );
 
-    # merge the both plugins types together
+    # Merge the both plug-in types together.
     my @PluginFilesAll = ( @PluginFiles, @PluginAsynchronousFiles );
 
     my @Result;
 
-    # Execute all Plugins
+    # Execute all plug-ins.
+    PLUGINFILE:
     for my $PluginFile (@PluginFilesAll) {
 
         # Convert file name => package name
         $PluginFile =~ s{^.*(Kernel/System.*)[.]pm$}{$1}xmsg;
         $PluginFile =~ s{/+}{::}xmsg;
 
+        next PLUGINFILE if $LookupPluginDisabled{$PluginFile};
+
         if ( !$Kernel::OM->Get('Kernel::System::Main')->Require($PluginFile) ) {
             return (
                 Success      => 0,
@@ -159,16 +175,19 @@ sub Collect {
 
         if ( !%PluginResult || !$PluginResult{Success} ) {
             return (
-                Success => 0,
-                ErrorMessage =>
-                    "Error during execution of $PluginFile: $PluginResult{ErrorMessage}",
+                Success      => 0,
+                ErrorMessage => "Error during execution of $PluginFile: $PluginResult{ErrorMessage}",
             );
         }
 
         push @Result, @{ $PluginResult{Result} // [] };
     }
 
-    # sort the results from the plugins by the short identifier
+    # Remove the disabled plugins after the execution, because some plugins returns
+    #   more information with a own identifier.
+    @Result = grep { !$LookupIdentifierFilterBlacklist{ $_->{Identifier} } } @Result;
+
+    # Sort the results from the plug-ins by the short identifier.
     @Result = sort { $a->{ShortIdentifier} cmp $b->{ShortIdentifier} } @Result;
 
     my %ReturnData = (
@@ -176,13 +195,17 @@ sub Collect {
         Result  => \@Result,
     );
 
-    # set cache
-    $Kernel::OM->Get('Kernel::System::Cache')->Set(
-        Type  => 'SupportDataCollector',
-        Key   => $CacheKey,
-        Value => \%ReturnData,
-        TTL   => 60 * 10,
-    );
+    # Cache the result only, if the support data were collected in a web request,
+    #   to have all support data in the admin view.
+    if ( $ENV{GATEWAY_INTERFACE} ) {
+
+        $Kernel::OM->Get('Kernel::System::Cache')->Set(
+            Type  => 'SupportDataCollector',
+            Key   => $CacheKey,
+            Value => \%ReturnData,
+            TTL   => 60 * 10,
+        );
+    }
 
     return %ReturnData;
 }
@@ -194,7 +217,7 @@ sub CollectByWebRequest {
     #   PublicSupportDataCollector requires this ChallengeToken.
     my $ChallengeToken = $Kernel::OM->Get('Kernel::System::Main')->GenerateRandomString(
         Length     => 32,
-        Dictionary => [ 0 .. 9, 'a' .. 'f' ],    # hexadecimal
+        Dictionary => [ 0 .. 9, 'a' .. 'f' ],    # Generate a hexadecimal value.
     );
 
     if (
@@ -215,41 +238,56 @@ sub CollectByWebRequest {
         );
     }
 
-    my $Host;
-    my $FQDN = $Kernel::OM->Get('Kernel::Config')->Get('FQDN');
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
 
-    if ( $FQDN ne 'yourhost.example.com' && gethostbyname($FQDN) ) {
-        $Host = $FQDN;
+    my $Host = $ConfigObject->Get('SupportDataCollector::HTTPHostname');
+
+    if ( !$Host ) {
+
+        my $FQDN = $ConfigObject->Get('FQDN');
+
+        if ( $FQDN ne 'yourhost.example.com' && gethostbyname($FQDN) ) {
+            $Host = $FQDN;
+        }
+
+        if ( !$Host && gethostbyname('localhost') ) {
+            $Host = 'localhost';
+        }
+
+        $Host ||= '127.0.0.1';
     }
 
-    if ( !$Host && gethostbyname('localhost') ) {
-        $Host = 'localhost';
+    # If the public interface is proteceted with .htaccess
+    #   we can specify the htaccess login data here,
+    #   this is neccessary for the support data collector.
+    my $AuthString   = '';
+    my $AuthUser     = $ConfigObject->Get('PublicFrontend::AuthUser');
+    my $AuthPassword = $ConfigObject->Get('PublicFrontend::AuthPassword');
+    if ( $AuthUser && $AuthPassword ) {
+        $AuthString = $AuthUser . ':' . $AuthPassword . '@';
     }
 
-    $Host ||= '127.0.0.1';
-
-    # prepare webservice config
+    # Prepare web service config for the internal web request.
     my $URL =
-        $Kernel::OM->Get('Kernel::Config')->Get('HttpType')
+        $ConfigObject->Get('HttpType')
         . '://'
         . $Host
         . '/'
-        . $Kernel::OM->Get('Kernel::Config')->Get('ScriptAlias')
+        . $ConfigObject->Get('ScriptAlias')
         . 'public.pl';
 
-    # create webuseragent object
     my $WebUserAgentObject = Kernel::System::WebUserAgent->new(
         Timeout => $Param{WebTimeout} || 20,
     );
 
-    # disable webuseragent proxy since the call is sent to self server, see bug#11680
+    # Disable webuseragent proxy since the call is sent to self server, see bug#11680.
     $WebUserAgentObject->{Proxy} = '';
 
-    # define result
     my %Result = (
         Success => 0,
     );
 
+    # Skip the ssl verification, because this is only a internal web request.
     my %Response = $WebUserAgentObject->Request(
         Type => 'POST',
         URL  => $URL,
@@ -258,26 +296,30 @@ sub CollectByWebRequest {
             ChallengeToken => $ChallengeToken,
         },
         SkipSSLVerification => 1,
+        NoLog               => $Self->{Debug} ? 0 : 1,
     );
 
-    # test if the web response was successful
     if ( $Response{Status} ne '200 OK' ) {
-        $Result{ErrorMessage} = "Can't connect to server - $Response{Status}";
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'notice',
-            Message  => "SupportDataCollector - $Result{ErrorMessage}",
-        );
+
+        if ( $Self->{Debug} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'notice',
+                Message  => "SupportDataCollector - Can't connect to server - $Response{Status}",
+            );
+        }
 
         return %Result;
     }
 
     # check if we have content as a scalar ref
     if ( !$Response{Content} || ref $Response{Content} ne 'SCALAR' ) {
-        $Result{ErrorMessage} = 'No content received.';
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'notice',
-            Message  => "SupportDataCollector - $Result{ErrorMessage}",
-        );
+
+        if ( $Self->{Debug} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'notice',
+                Message  => "SupportDataCollector - No content received.",
+            );
+        }
         return %Result;
     }
 
@@ -286,11 +328,14 @@ sub CollectByWebRequest {
 
     # Discard HTML responses (error pages etc.).
     if ( substr( ${ $Response{Content} }, 0, 1 ) eq '<' ) {
-        $Result{ErrorMessage} = 'Response looks like HTML instead of JSON.';
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'notice',
-            Message  => "SupportDataCollector - $Result{ErrorMessage}",
-        );
+
+        if ( $Self->{Debug} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'notice',
+                Message  => "SupportDataCollector - Response looks like HTML instead of JSON.",
+            );
+        }
+
         return %Result;
     }
 
@@ -299,22 +344,16 @@ sub CollectByWebRequest {
         Data => ${ $Response{Content} },
     );
     if ( !$ResponseData || ref $ResponseData ne 'HASH' ) {
-        $Result{ErrorMessage} = "Can't decode JSON: '" . ${ $Response{Content} } . "'!";
-        $Kernel::OM->Get('Kernel::System::Log')->Log(
-            Priority => 'error',
-            Message  => "SupportDataCollector - $Result{ErrorMessage}",
-        );
+
+        if ( $Self->{Debug} ) {
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
+                Priority => 'error',
+                Message  => "SupportDataCollector - Can't decode JSON: '" . ${ $Response{Content} } . "'!",
+            );
+        }
         return %Result;
     }
 
-    # set cache
-    $Kernel::OM->Get('Kernel::System::Cache')->Set(
-        Type  => 'SupportDataCollect',
-        Key   => 'DataCollect',
-        Value => $ResponseData,
-        TTL   => 60 * 10,
-    );
-
     return %{$ResponseData};
 }
 
@@ -410,11 +449,11 @@ sub CleanupAsynchronous {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
 
