@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -19,24 +19,30 @@ our @ObjectDependencies = (
     'Kernel::System::DB',
     'Kernel::System::Log',
     'Kernel::System::Main',
-    'Kernel::System::DateTime',
+    'Kernel::System::Time',
     'Kernel::System::Valid',
 );
 
 =head1 NAME
 
-Kernel::System::SystemMaintenance
+Kernel::System::SystemMaintenance.pm
 
-=head1 DESCRIPTION
+=head1 SYNOPSIS
 
 SystemMaintenance backend
 
 =head1 PUBLIC INTERFACE
 
-=head2 new()
+=over 4
+
+=cut
+
+=item new()
 
 create a SystemMaintenance object. Do not use it directly, instead use:
 
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
     my $SystemMaintenanceObject = $Kernel::OM->Get('Kernel::System::SystemMaintenance');
 
 =cut
@@ -51,7 +57,7 @@ sub new {
     return $Self;
 }
 
-=head2 SystemMaintenanceAdd()
+=item SystemMaintenanceAdd()
 
 add new SystemMaintenance
 
@@ -91,10 +97,6 @@ sub SystemMaintenanceAdd {
     # date start shouldn't be higher than stop date
     return if ( $Param{StartDate} > $Param{StopDate} );
 
-    # Database columns for LoginMessage and NotifyMessage in system_maintenance are limited to 250 characters.
-    return if $Param{LoginMessage}  && length $Param{LoginMessage} > 250;
-    return if $Param{NotifyMessage} && length $Param{NotifyMessage} > 250;
-
     # get database object
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
 
@@ -132,7 +134,7 @@ sub SystemMaintenanceAdd {
     return $ID;
 }
 
-=head2 SystemMaintenanceDelete()
+=item SystemMaintenanceDelete()
 
 delete a SystemMaintenance
 
@@ -179,7 +181,7 @@ sub SystemMaintenanceDelete {
     return 1;
 }
 
-=head2 SystemMaintenanceGet()
+=item SystemMaintenanceGet()
 
 get SystemMaintenance attributes
 
@@ -260,7 +262,7 @@ sub SystemMaintenanceGet {
     return \%Data;
 }
 
-=head2 SystemMaintenanceUpdate()
+=item SystemMaintenanceUpdate()
 
 update SystemMaintenance attributes
 
@@ -297,10 +299,6 @@ sub SystemMaintenanceUpdate {
     # date start shouldn't be higher than stop date
     return if ( $Param{StartDate} > $Param{StopDate} );
 
-    # Database columns for LoginMessage and NotifyMessage in system_maintenance table are limited to 250 characters.
-    return if $Param{LoginMessage}  && length $Param{LoginMessage} > 250;
-    return if $Param{NotifyMessage} && length $Param{NotifyMessage} > 250;
-
     # get database object
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
 
@@ -321,7 +319,7 @@ sub SystemMaintenanceUpdate {
     return 1;
 }
 
-=head2 SystemMaintenanceList()
+=item SystemMaintenanceList()
 
 get an SystemMaintenance list
 
@@ -386,7 +384,7 @@ sub SystemMaintenanceList {
     return \%Data;
 }
 
-=head2 SystemMaintenanceListGet()
+=item SystemMaintenanceListGet()
 
 get an SystemMaintenance list with all SystemMaintenance details
 
@@ -460,7 +458,7 @@ sub SystemMaintenanceListGet {
     return \@Data;
 }
 
-=head2 SystemMaintenanceIsActive()
+=item SystemMaintenanceIsActive()
 
 get a SystemMaintenance active flag
 
@@ -475,8 +473,7 @@ Returns:
 sub SystemMaintenanceIsActive {
     my ( $Self, %Param ) = @_;
 
-    my $DateTimeObject = $Kernel::OM->Create('Kernel::System::DateTime');
-    my $SystemTime     = $DateTimeObject->ToEpoch();
+    my $SystemTime = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
 
     # get database object
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
@@ -510,38 +507,32 @@ sub SystemMaintenanceIsActive {
     return $Result;
 }
 
-=head2 SystemMaintenanceIsComing()
+=item SystemMaintenanceIsComming()
 
-Get a upcoming SystemMaintenance start and stop date.
+get a SystemMaintenance flag
 
-    my %SystemMaintenanceIsComing = $SystemMaintenanceObject->SystemMaintenanceIsComing();
+    my $SystemMaintenanceIsComming = $SystemMaintenanceObject->SystemMaintenanceIsComming();
 
 Returns:
 
-    %SystemMaintenanceIsComing = {
-        StartDate => 1515614400,
-        StopDate  => 1515607200
-    };
+    $SystemMaintenanceIsComming = 1 # 1 or 0
 
 =cut
 
-sub SystemMaintenanceIsComing {
+sub SystemMaintenanceIsComming {
     my ( $Self, %Param ) = @_;
 
-    my $DateTimeObject = $Kernel::OM->Create('Kernel::System::DateTime');
-    my $SystemTime     = $DateTimeObject->ToEpoch();
-
+    my $SystemTime = $Kernel::OM->Get('Kernel::System::Time')->SystemTime();
     my $NotifiBeforeTime =
         $Kernel::OM->Get('Kernel::Config')->Get('SystemMaintenance::TimeNotifyUpcomingMaintenance')
         || 30;
-    $DateTimeObject->Add( Minutes => $NotifiBeforeTime );
-    my $TargetTime = $DateTimeObject->ToEpoch();
+    my $TargetTime = $SystemTime + ( $NotifiBeforeTime * 60 );
 
     # get database object
     my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
 
     my $SQL = "
-            SELECT start_date, stop_date
+            SELECT start_date
             FROM system_maintenance
             WHERE start_date > $SystemTime and start_date <= $TargetTime
     ";
@@ -557,21 +548,22 @@ sub SystemMaintenanceIsComing {
 
     return if !$DBObject->Prepare( SQL => $SQL );
 
-    my %Result;
+    my $Result;
     RESULT:
     while ( my @Row = $DBObject->FetchrowArray() ) {
-        $Result{StartDate} = $Row[0];
-        $Result{StopDate}  = $Row[1];
+        $Result = $Row[0];
         last RESULT;
     }
 
-    return if !%Result;
+    return if !$Result;
 
-    return %Result;
+    return $Result;
 }
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (L<https://otrs.org/>).
