@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::UnitTest::Selenium;
@@ -24,7 +24,7 @@ our @ObjectDependencies = (
     'Kernel::System::Log',
     'Kernel::System::Main',
     'Kernel::System::Time',
-    'Kernel::System::UnitTest',
+    'Kernel::System::UnitTest::Driver',
     'Kernel::System::UnitTest::Helper',
 );
 
@@ -72,15 +72,15 @@ Then you can use the full API of Selenium::Remote::Driver on this object.
 sub new {
     my ( $Class, %Param ) = @_;
 
-    $Param{UnitTestObject} ||= $Kernel::OM->Get('Kernel::System::UnitTest');
+    $Param{UnitTestDriverObject} ||= $Kernel::OM->Get('Kernel::System::UnitTest::Driver');
 
-    $Param{UnitTestObject}->True( 1, "Starting up Selenium scenario..." );
+    $Param{UnitTestDriverObject}->True( 1, "Starting up Selenium scenario..." );
 
     my %SeleniumTestsConfig = %{ $Kernel::OM->Get('Kernel::Config')->Get('SeleniumTestsConfig') // {} };
 
     if ( !%SeleniumTestsConfig ) {
         my $Self = bless {}, $Class;
-        $Self->{UnitTestObject} = $Param{UnitTestObject};
+        $Self->{UnitTestDriverObject} = $Param{UnitTestDriverObject};
         return $Self;
     }
 
@@ -100,8 +100,8 @@ sub new {
         webelement_class => 'Kernel::System::UnitTest::Selenium::WebElement',
         %SeleniumTestsConfig
     );
-    $Self->{UnitTestObject}      = $Param{UnitTestObject};
-    $Self->{SeleniumTestsActive} = 1;
+    $Self->{UnitTestDriverObject} = $Param{UnitTestDriverObject};
+    $Self->{SeleniumTestsActive}  = 1;
 
     #$Self->debug_on();
 
@@ -149,7 +149,7 @@ sub RunTest {
     my ( $Self, $Test ) = @_;
 
     if ( !$Self->{SeleniumTestsActive} ) {
-        $Self->{UnitTestObject}->True( 1, 'Selenium testing is not active, skipping tests.' );
+        $Self->{UnitTestDriverObject}->True( 1, 'Selenium testing is not active, skipping tests.' );
         return 1;
     }
 
@@ -183,7 +183,7 @@ sub _execute_command {    ## no critic
         }
     );
 
-    $Self->{UnitTestObject}->True(
+    $Self->{UnitTestDriverObject}->True(
         1,
         $TestName
     );
@@ -307,7 +307,7 @@ sub Login {
         }
     }
 
-    $Self->{UnitTestObject}->True( 1, 'Initiating login...' );
+    $Self->{UnitTestDriverObject}->True( 1, 'Initiating login...' );
 
     # we will try several times to log in
     my $MaxTries = 5;
@@ -333,13 +333,13 @@ sub Login {
             # login successful?
             $Self->find_element( 'a#LogoutButton', 'css' );    # dies if not found
 
-            $Self->{UnitTestObject}->True( 1, 'Login sequence ended...' );
+            $Self->{UnitTestDriverObject}->True( 1, 'Login sequence ended...' );
         };
 
         # an error happend
         if ($@) {
 
-            $Self->{UnitTestObject}->True( 1, "Login attempt $Try of $MaxTries not successful." );
+            $Self->{UnitTestDriverObject}->True( 1, "Login attempt $Try of $MaxTries not successful." );
 
             # try again
             next TRY if $Try < $MaxTries;
@@ -384,7 +384,7 @@ sub WaitFor {
 
     while ( $WaitedSeconds <= $Param{Time} ) {
         if ( $Param{JavaScript} ) {
-            return 1 if $Self->execute_script( $Param{JavaScript} )
+            return 1 if $Self->execute_script( $Param{JavaScript} );
         }
         elsif ( $Param{WindowCount} ) {
             return 1 if scalar( @{ $Self->get_window_handles() } ) == $Param{WindowCount};
@@ -410,7 +410,7 @@ for analysis (in folder /var/otrs-unittest if it exists, in $Home/var/httpd/htdo
 sub HandleError {
     my ( $Self, $Error ) = @_;
 
-    $Self->{UnitTestObject}->False( 1, "Exception in Selenium': $Error" );
+    $Self->{UnitTestDriverObject}->False( 1, "Exception in Selenium': $Error" );
 
     #eval {
     my $Data = $Self->screenshot();
@@ -451,11 +451,12 @@ sub HandleError {
             Directory => $SharedScreenshotDir,
             Filename  => $Filename,
             Content   => \$Data,
-        ) || return $Self->{UnitTestObject}->False( 1, "Could not write file $SharedScreenshotDir/$Filename" );
+            )
+            || return $Self->{UnitTestDriverObject}->False( 1, "Could not write file $SharedScreenshotDir/$Filename" );
     }
 
-    $Self->{UnitTestObject}->False( 1, "Saved screenshot in $URL" );
-    $Self->{UnitTestObject}->AttachSeleniumScreenshot(
+    $Self->{UnitTestDriverObject}->False( 1, "Saved screenshot in $URL" );
+    $Self->{UnitTestDriverObject}->AttachSeleniumScreenshot(
         Filename => $Filename,
         Content  => $Data
     );
@@ -472,40 +473,41 @@ sub DEMOLISH {
     my $Self = shift;
 
     # Could be missing on early die.
-    if ( $Self->{UnitTestObject} ) {
-        $Self->{UnitTestObject}->True( 1, "Shutting down Selenium scenario." );
+    if ( $Self->{UnitTestDriverObject} ) {
+        $Self->{UnitTestDriverObject}->True( 1, "Shutting down Selenium scenario." );
     }
 
     if ( $Self->{SeleniumTestsActive} ) {
         $Self->SUPER::DEMOLISH(@_);
-    }
 
-    # Cleanup possibly leftover zombie firefox profiles.
-    my @LeftoverFirefoxProfiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
-        Directory => '/tmp/',
-        Filter    => 'anonymous*webdriver-profile',
-    );
+        # Cleanup possibly leftover zombie firefox profiles.
+        my @LeftoverFirefoxProfiles = $Kernel::OM->Get('Kernel::System::Main')->DirectoryRead(
+            Directory => '/tmp/',
+            Filter    => 'anonymous*webdriver-profile',
+        );
 
-    for my $LeftoverFirefoxProfile (@LeftoverFirefoxProfiles) {
-        if ( -d $LeftoverFirefoxProfile ) {
-            File::Path::remove_tree($LeftoverFirefoxProfile);
+        for my $LeftoverFirefoxProfile (@LeftoverFirefoxProfiles) {
+            if ( -d $LeftoverFirefoxProfile ) {
+                File::Path::remove_tree($LeftoverFirefoxProfile);
+            }
         }
-    }
 
-    # Cleanup all sessions, which was created after the selenium test start time.
-    my $AuthSessionObject = $Kernel::OM->Get('Kernel::System::AuthSession');
+        # Cleanup all sessions, which was created after the selenium test start time.
+        my $AuthSessionObject = $Kernel::OM->Get('Kernel::System::AuthSession');
 
-    my @Sessions = $AuthSessionObject->GetAllSessionIDs();
+        my @Sessions = $AuthSessionObject->GetAllSessionIDs();
 
-    SESSION:
-    for my $SessionID (@Sessions) {
+        SESSION:
+        for my $SessionID (@Sessions) {
 
-        my %SessionData = $AuthSessionObject->GetSessionIDData( SessionID => $SessionID );
+            my %SessionData = $AuthSessionObject->GetSessionIDData( SessionID => $SessionID );
 
-        next SESSION if !%SessionData;
-        next SESSION if $SessionData{UserSessionStart} && $SessionData{UserSessionStart} < $Self->{TestStartSystemTime};
+            next SESSION if !%SessionData;
+            next SESSION
+                if $SessionData{UserSessionStart} && $SessionData{UserSessionStart} < $Self->{TestStartSystemTime};
 
-        $AuthSessionObject->RemoveSessionID( SessionID => $SessionID );
+            $AuthSessionObject->RemoveSessionID( SessionID => $SessionID );
+        }
     }
 }
 
@@ -515,10 +517,10 @@ sub DEMOLISH {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
