@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -11,13 +11,15 @@ package scripts::test::ObjectManager::Dummy;    ## no critic
 use strict;
 use warnings;
 
+use Kernel::System::ObjectManager;
+
 ## nofilter(TidyAll::Plugin::OTRS::Perl::ObjectDependencies)
 our @ObjectDependencies = ();                   # we want to use an undeclared dependency for testing
 
 sub new {
     my ( $Class, %Param ) = @_;
+
     bless \%Param, $Class;
-    return \%Param;
 }
 
 sub Data {
@@ -30,8 +32,6 @@ sub DESTROY {
     # Request this object (undeclared dependency) in the desctructor.
     #   This will create it again in the OM to test that ObjectsDiscard will still work.
     $Kernel::OM->Get('scripts::test::ObjectManager::Dummy2');
-
-    return;
 }
 
 1;
