@@ -1,9 +1,9 @@
 // --
-// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (AGPL). If you
-// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+// the enclosed file COPYING for license information (GPL). If you
+// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 // --
 
 "use strict";
@@ -445,7 +445,7 @@ Core.Agent.Search = (function (TargetNS) {
                         else {
                             CheckSearchStringsForStopWords( function () {
                                 $('#SearchForm').submit();
-                                ShowWaitingDialog();
+                                return false;
                            });
                         }
                     }
@@ -464,6 +464,17 @@ Core.Agent.Search = (function (TargetNS) {
                     return false;
                 });
 
+                Core.Form.Validate.Init();
+                Core.Form.Validate.SetSubmitFunction($('#SearchForm'), function (Form) {
+                    Form.submit();
+
+                    // Show only a waiting dialog for Normal results mode, because this result
+                    //  will return the HTML in the same window.
+                    if ($('#SearchForm #ResultForm').val() === 'Normal') {
+                        ShowWaitingDialog();
+                    }
+                });
+
                 // load profile
                 $('#SearchProfile').bind('change', function () {
                     var Profile = $('#SearchProfile').val(),
