@@ -1,5 +1,5 @@
 // --
-// Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+// Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (GPL). If you
@@ -12,11 +12,10 @@ var Core = Core || {};
 Core.Agent = Core.Agent || {};
 
 /**
- * @namespace Core.Agent.TableFilters
- * @memberof Core.Agent
- * @author OTRS AG
+ * @namespace
+ * @exports TargetNS as Core.Agent.TableFilters
  * @description
- *      This namespace contains the special module functions for the table filters.
+ *      This namespace contains the special module functions for the Dashboard.
  */
 Core.Agent.TableFilters = (function (TargetNS) {
 
@@ -24,27 +23,18 @@ Core.Agent.TableFilters = (function (TargetNS) {
      * check dependencies first
      */
     if (!Core.Debug.CheckDependency('Core.Agent.TableFilters', 'Core.UI.AllocationList', 'Core.UI.AllocationList')) {
-        return false;
+        return;
     }
 
     /**
-     * @name InitCustomerIDAutocomplete
-     * @memberof Core.Agent.TableFilters
      * @function
-     * @param {jQueryObject} $Input - Input element to add auto complete to.
-     * @description
-     *      Initialize autocompletion for CustomerID.
+     * @param {jQueryObject} $Input Input element to add auto complete to
+     * @return nothing
      */
     TargetNS.InitCustomerIDAutocomplete = function ($Input) {
-        var AutoCompleteConfig = Core.Config.Get('CustomerIDAutocomplete');
-
-        if (typeof AutoCompleteConfig === 'undefined') {
-            return;
-        }
-
         $Input.autocomplete({
-            minLength: AutoCompleteConfig.MinQueryLength,
-            delay: AutoCompleteConfig.QueryDelay,
+            minLength: Core.Config.Get('CustomerIDAutocomplete.MinQueryLength'),
+            delay: Core.Config.Get('CustomerIDAutocomplete.QueryDelay'),
             open: function() {
                 // force a higher z-index than the overlay/dialog
                 $(this).autocomplete('widget').addClass('ui-overlay-autocomplete');
@@ -52,11 +42,11 @@ Core.Agent.TableFilters = (function (TargetNS) {
             },
             source: function (Request, Response) {
                 var URL = Core.Config.Get('Baselink'), Data = {
-                    Action: 'AgentCustomerSearch',
+                    Action: 'AgentCustomerInformationCenterSearch',
+                    IncludeUnknownTicketCustomers: Core.Config.Get('IncludeUnknownTicketCustomers'),
                     Subaction: 'SearchCustomerID',
-                    IncludeUnknownTicketCustomers: parseInt(Core.Config.Get('IncludeUnknownTicketCustomers'), 10),
                     Term: Request.term,
-                    MaxResults: AutoCompleteConfig.MaxResultsDisplayed
+                    MaxResults: Core.Config.Get('CustomerIDAutocomplete.MaxResultsDisplayed')
                 };
 
                 // if an old ajax request is already running, stop the old request and start the new one
@@ -68,15 +58,15 @@ Core.Agent.TableFilters = (function (TargetNS) {
                 }
 
                 $Input.data('AutoCompleteXHR', Core.AJAX.FunctionCall(URL, Data, function (Result) {
-                    var ValueData = [];
+                    var Data = [];
                     $Input.removeData('AutoCompleteXHR');
                     $.each(Result, function () {
-                        ValueData.push({
+                        Data.push({
                             label: this.Label + ' (' + this.Value + ')',
                             value: this.Value
                         });
                     });
-                    Response(ValueData);
+                    Response(Data);
                 }));
             },
             select: function (Event, UI) {
@@ -91,23 +81,14 @@ Core.Agent.TableFilters = (function (TargetNS) {
     };
 
     /**
-     * @name InitCustomerUserAutocomplete
-     * @memberof Core.Agent.TableFilters
      * @function
-     * @param {jQueryObject} $Input - Input element to add auto complete to.
-     * @description
-     *      Initialize autocompletion for Customer User.
+     * @param {jQueryObject} $Input Input element to add auto complete to
+     * @return nothing
      */
     TargetNS.InitCustomerUserAutocomplete = function ($Input) {
-        var AutoCompleteConfig = Core.Config.Get('CustomerUserAutocomplete');
-
-        if (typeof AutoCompleteConfig === 'undefined') {
-            return;
-        }
-
         $Input.autocomplete({
-            minLength: AutoCompleteConfig.MinQueryLength,
-            delay: AutoCompleteConfig.QueryDelay,
+            minLength: Core.Config.Get('CustomerUserAutocomplete.MinQueryLength'),
+            delay: Core.Config.Get('CustomerUserAutocomplete.QueryDelay'),
             open: function() {
                 // force a higher z-index than the overlay/dialog
                 $(this).autocomplete('widget').addClass('ui-overlay-autocomplete');
@@ -116,9 +97,9 @@ Core.Agent.TableFilters = (function (TargetNS) {
             source: function (Request, Response) {
                 var URL = Core.Config.Get('Baselink'), Data = {
                     Action: 'AgentCustomerSearch',
-                    IncludeUnknownTicketCustomers: parseInt(Core.Config.Get('IncludeUnknownTicketCustomers'), 10),
+                    IncludeUnknownTicketCustomers: Core.Config.Get('IncludeUnknownTicketCustomers'),
                     Term: Request.term,
-                    MaxResults: AutoCompleteConfig.MaxResultsDisplayed
+                    MaxResults: Core.Config.Get('CustomerUserAutocomplete.MaxResultsDisplayed')
                 };
 
                 // if an old ajax request is already running, stop the old request and start the new one
@@ -130,16 +111,16 @@ Core.Agent.TableFilters = (function (TargetNS) {
                 }
 
                 $Input.data('AutoCompleteXHR', Core.AJAX.FunctionCall(URL, Data, function (Result) {
-                    var ValueData = [];
+                    var Data = [];
                     $Input.removeData('AutoCompleteXHR');
                     $.each(Result, function () {
-                        ValueData.push({
-                            label: this.Label + " (" + this.Value + ")",
-                            value: this.Label,
-                            key: this.Value
+                        Data.push({
+                            label: this.CustomerValue + " (" + this.CustomerKey + ")",
+                            value: this.CustomerValue,
+                            key: this.CustomerKey
                         });
                     });
-                    Response(ValueData);
+                    Response(Data);
                 }));
             },
             select: function (Event, UI) {
@@ -154,24 +135,15 @@ Core.Agent.TableFilters = (function (TargetNS) {
     };
 
     /**
-     * @name InitUserAutocomplete
-     * @memberof Core.Agent.TableFilters
      * @function
-     * @param {jQueryObject} $Input - Input element to add auto complete to.
-     * @param {String} Subaction  - Subaction to execute, "SearchCustomerID" or "SearchCustomerUser"
-     * @description
-     *      Initialize autocompletion for User.
+     * @param {jQueryObject} $Input Input element to add auto complete to
+     * @param {String} Subaction Subaction to execute, "SearchCustomerID" or "SearchCustomerUser"
+     * @return nothing
      */
     TargetNS.InitUserAutocomplete = function ($Input, Subaction) {
-        var AutoCompleteConfig = Core.Config.Get('UserAutocomplete');
-
-        if (typeof AutoCompleteConfig === 'undefined') {
-            return;
-        }
-
         $Input.autocomplete({
-            minLength: AutoCompleteConfig.MinQueryLength,
-            delay: AutoCompleteConfig.QueryDelay,
+            minLength: Core.Config.Get('UserAutocomplete.MinQueryLength'),
+            delay: Core.Config.Get('UserAutocomplete.QueryDelay'),
             open: function() {
                 // force a higher z-index than the overlay/dialog
                 $(this).autocomplete('widget').addClass('ui-overlay-autocomplete');
@@ -182,7 +154,7 @@ Core.Agent.TableFilters = (function (TargetNS) {
                     Action: 'AgentUserSearch',
                     Subaction: Subaction,
                     Term: Request.term,
-                    MaxResults: AutoCompleteConfig.MaxResultsDisplayed
+                    MaxResults: Core.Config.Get('UserAutocomplete.MaxResultsDisplayed')
                 };
 
                 // if an old ajax request is already running, stop the old request and start the new one
@@ -194,16 +166,16 @@ Core.Agent.TableFilters = (function (TargetNS) {
                 }
 
                 $Input.data('AutoCompleteXHR', Core.AJAX.FunctionCall(URL, Data, function (Result) {
-                    var ValueData = [];
+                    var Data = [];
                     $Input.removeData('AutoCompleteXHR');
                     $.each(Result, function () {
-                        ValueData.push({
+                        Data.push({
                             label: this.UserValue + " (" + this.UserKey + ")",
                             value: this.UserValue,
                             key: this.UserKey
                         });
                     });
-                    Response(ValueData);
+                    Response(Data);
                 }));
             },
             select: function (Event, UI) {
@@ -217,12 +189,11 @@ Core.Agent.TableFilters = (function (TargetNS) {
         });
     };
 
+
     /**
-     * @name Init
-     * @memberof Core.Agent.TableFilters
      * @function
-     * @description
-     *      This function initializes the special module functions.
+     * @return nothing
+     *      This function initializes the special module functions
      */
     TargetNS.Init = function () {
             // Initiate allocation list
@@ -231,14 +202,11 @@ Core.Agent.TableFilters = (function (TargetNS) {
 
 
     /**
-     * @private
-     * @name UpdateAllocationList
-     * @memberof Core.Agent.TableFilters
      * @function
-     * @param {Object} Event
-     * @param {Object} UI - jQuery UI object
-     * @description
-     *      Update allocation list entries.
+     * @private
+     * @param {string} FieldID Id of the field which is updated via ajax
+     * @param {string} Show Show or hide the AJAX loader image
+     * @description Shows and hides an ajax loader for every element which is updates via ajax
      */
     function UpdateAllocationList(Event, UI) {
 
@@ -251,7 +219,7 @@ Core.Agent.TableFilters = (function (TargetNS) {
         }
 
         Data.Columns = {};
-        Data.Order = [];
+        Data.Order   = [];
 
         $ContainerObj.find('.AvailableFields').find('li').each(function() {
             FieldName = $(this).attr('data-fieldname');
@@ -267,30 +235,18 @@ Core.Agent.TableFilters = (function (TargetNS) {
     }
 
     /**
-     * @name SetAllocationList
-     * @memberof Core.Agent.TableFilters
      * @function
-     * @param {String} Name - Widget link table object name.
-     * @description
-     *      Initialize allocation list.
+     * @return nothing
+     *      This function binds a click event on an html element to update the preferences of the given dahsboard widget
+     * @param {jQueryObject} $ClickedElement The jQuery object of the element(s) that get the event listener
+     * @param {string} ElementID The ID of the element whose content should be updated with the server answer
+     * @param {jQueryObject} $Form The jQuery object of the form with the data for the server request
      */
-    TargetNS.SetAllocationList = function (Name) {
-        var AllocationListArray = [];
-
-        // Narrow down case when there are multiple link object tables, to updated only expected one.
-        if (typeof Name !== 'undefined') {
-            AllocationListArray.push($('#Widget' + Name + ' .AllocationListContainer'));
-        }
-        else {
-            $('.AllocationListContainer').each(function() {
-                AllocationListArray.push($(this));
-            });
-        }
-
-        $.each(AllocationListArray, function() {
+    TargetNS.SetAllocationList = function (Event, UI) {
+        $('.AllocationListContainer').each(function() {
 
             var $ContainerObj = $(this),
-                DataEnabledJSON = $ContainerObj.closest('form.WidgetSettingsForm').find('input.ColumnsEnabledJSON').val(),
+                DataEnabledJSON   = $ContainerObj.closest('form.WidgetSettingsForm').find('input.ColumnsEnabledJSON').val(),
                 DataAvailableJSON = $ContainerObj.closest('form.WidgetSettingsForm').find('input.ColumnsAvailableJSON').val(),
                 DataEnabled,
                 DataAvailable,
@@ -310,7 +266,7 @@ Core.Agent.TableFilters = (function (TargetNS) {
                 // get field translation
                 Translation = Core.Config.Get('Column' + Field) || Field;
 
-                $FieldObj = $('<li />').attr('title', Translation).attr('data-fieldname', Field).text(Translation);
+                $FieldObj = $('<li />').attr('title', Field).attr('data-fieldname', Field).text(Translation);
                 $ContainerObj.find('.AssignedFields').append($FieldObj);
             });
             $.each(DataAvailable, function(Index, Field) {
@@ -318,7 +274,7 @@ Core.Agent.TableFilters = (function (TargetNS) {
                 // get field translation
                 Translation = Core.Config.Get('Column' + Field) || Field;
 
-                $FieldObj = $('<li />').attr('title', Translation).attr('data-fieldname', Field).text(Translation);
+                $FieldObj = $('<li />').attr('title', Field).attr('data-fieldname', Field).text(Translation);
                 $ContainerObj.find('.AvailableFields').append($FieldObj);
             });
 
@@ -327,15 +283,14 @@ Core.Agent.TableFilters = (function (TargetNS) {
         });
     };
 
+
     /**
-     * @name RegisterUpdatePreferences
-     * @memberof Core.Agent.TableFilters
      * @function
-     * @param {jQueryObject} $ClickedElement - The jQuery object of the element(s) that get the event listener
-     * @param {String} ElementID - The ID of the element whose content should be updated with the server answer
-     * @param {jQueryObject} $Form - The jQuery object of the form with the data for the server request
-     * @description
-     *      This function binds a click event on an html element to update the preferences of the given dahsboard widget.
+     * @return nothing
+     *      This function binds a click event on an html element to update the preferences of the given dahsboard widget
+     * @param {jQueryObject} $ClickedElement The jQuery object of the element(s) that get the event listener
+     * @param {string} ElementID The ID of the element whose content should be updated with the server answer
+     * @param {jQueryObject} $Form The jQuery object of the form with the data for the server request
      */
     TargetNS.RegisterUpdatePreferences = function ($ClickedElement, ElementID, $Form) {
         if (isJQueryObject($ClickedElement) && $ClickedElement.length) {
@@ -343,11 +298,13 @@ Core.Agent.TableFilters = (function (TargetNS) {
                 var URL = Core.Config.Get('Baselink') + Core.AJAX.SerializeForm($Form);
                 Core.AJAX.ContentUpdate($('#' + ElementID), URL, function () {
                     Core.UI.ToggleTwoContainer($('#' + ElementID + '-setting'), $('#' + ElementID));
+                    Core.UI.Table.InitCSSPseudoClasses();
                 });
                 return false;
             });
         }
     };
 
+
     return TargetNS;
 }(Core.Agent.TableFilters || {}));
