@@ -1,12 +1,9 @@
 // --
-// Core.UI.Dialog.js - Dialogs
-// Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-// --
-// $Id: Core.UI.Dialog.js,v 1.35.2.2 2013-01-02 12:57:22 mn Exp $
+// Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (AGPL). If you
-// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+// the enclosed file COPYING for license information (GPL). If you
+// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 // --
 
 "use strict";
@@ -34,11 +31,10 @@ Core.UI.Dialog = (function (TargetNS) {
 
     /**
      * @function
-     * @private
      * @return nothing
      * @description Adjusts the scrollable inner container of the dialog after every resizing.
      */
-    function AdjustScrollableHeight() {
+    function AdjustScrollableHeight(AllowAutoGrow) {
         // Check window height and adjust the scrollable height of InnerContent
         // Calculation:
         // Window height
@@ -52,7 +48,8 @@ Core.UI.Dialog = (function (TargetNS) {
 
         // if dialog height is more than 300px recalculate width of InnerContent to make it scrollable
         // if dialog is smaller than 300px this is not necessary
-        if (DialogHeight > 300) {
+        // if AllowAutoGrow is set, auto-resizing should be possible
+        if (AllowAutoGrow || DialogHeight > 300) {
             ContentScrollHeight = WindowHeight - ((DialogTopMargin - WindowScrollTop) * 2) - 100;
         }
         else {
@@ -151,7 +148,8 @@ Core.UI.Dialog = (function (TargetNS) {
      *               PositionRight: value (default: undefined) Defines the right position of the dialog window
      *               CloseOnClickOutside true|false (default: false) If true, clicking outside the dialog closes the dialog
      *               CloseOnEscape true|false (default: false) If true, pressing escape key closes the dialog
-     *               NotDraggableIE7: true|false (default: false) If true, the dialog is not draggable in IE7 (due to performance reasons)
+     *               AllowAutoGrow: true|false (default: false) If true, the InnerContent of the dialog can resize until the max window height is reached,
+     *                                                          If false (default), InnerContent of small dialogs does not resize over 200px
      *               Buttons: Array of Hashes with the following properties (buttons are placed in a div "footer" of the dialog):
      *                  Label: string Text of the button
      *                  Type: string 'Submit'|'Close' (default: none) Special type of the button - invokes a standard function
@@ -217,7 +215,7 @@ Core.UI.Dialog = (function (TargetNS) {
         }
 
         var $Dialog, $Content, $ButtonFooter, ContentScrollHeight, HTMLBackup, DialogCopy, DialogCopySelector, $InnerContent, InnerContentWidth = 0,
-            DialogHTML = '<div class="Dialog"><div class="Header"><a class="Close" title="' + Core.Config.Get('DialogCloseMsg') + '" href="#"></a></div><div class="Content"></div><div class="Footer"></div></div>';
+            DialogHTML = '<div class="Dialog"><div class="Header"><a class="Close" title="' + Core.Config.Get('DialogCloseMsg') + '" href="#"><i class="fa fa-times"></i></a></div><div class="Content"></div><div class="Footer"></div></div>';
 
         // Close all opened dialogs
         if ($('.Dialog:visible').length) {
@@ -332,7 +330,7 @@ Core.UI.Dialog = (function (TargetNS) {
 
         // If Title is defined, add dialog title
         if (Params.Title) {
-            $Dialog.find('.Header').append('<h1>' + Params.Title + '</h1>');
+            $Dialog.find('div.Header').append('<h1>' + Params.Title + '</h1>');
         }
 
         // Add Dialog to page
@@ -342,8 +340,8 @@ Core.UI.Dialog = (function (TargetNS) {
         if ($Dialog.find('.Content .ContentFooter').length) {
             // change default Footer
             $Dialog.find('.Footer').addClass('ContentFooter');
-            // add special css for IE7
-            if ($.browser.msie && $.browser.version >= 7 && $.browser.version < 9) {
+            // add special css for IE8
+            if ($.browser.msie && $.browser.version === 8) {
                 $InnerContent = $Dialog.find('.Content .InnerContent');
                 InnerContentWidth = $InnerContent.width() + parseInt($InnerContent.css('padding-left'), 10) + parseInt($InnerContent.css('padding-right'), 10);
                 $Dialog.find('.Content .ContentFooter').width(InnerContentWidth);
@@ -382,22 +380,20 @@ Core.UI.Dialog = (function (TargetNS) {
         }
 
         // Check window height and adjust the scrollable height of InnerContent
-        AdjustScrollableHeight();
+        AdjustScrollableHeight(Params.AllowAutoGrow);
 
         // Add event-handling
-        if (!(Params.NotDraggableIE7 && $.browser.msie && parseInt($.browser.version, 10) === 7)) {
-            $Dialog.draggable({
-                containment: 'body',
-                handle: '.Header',
-                start: function(Event, UI) {
-                    // Hide any possibly existing tooltips as they will not be moved
-                    //  with this dialog.
-                    if (Core.Form && Core.Form.ErrorTooltips) {
-                        Core.Form.ErrorTooltips.HideTooltip();
-                    }
+        $Dialog.draggable({
+            containment: 'body',
+            handle: '.Header',
+            start: function(Event, UI) {
+                // Hide any possibly existing tooltips as they will not be moved
+                //  with this dialog.
+                if (Core.Form && Core.Form.ErrorTooltips) {
+                    Core.Form.ErrorTooltips.HideTooltip();
                 }
-            });
-        }
+            }
+        });
 
         // Add button events
         if (Params.Buttons) {
@@ -450,8 +446,8 @@ Core.UI.Dialog = (function (TargetNS) {
         }
 
         // Add resize event handler for calculating the scroll height
-        $(window).unbind('resize.Dialog').bind('resize.Dialog', function (event) {
-            AdjustScrollableHeight();
+        $(window).unbind('resize.Dialog').bind('resize.Dialog', function () {
+            AdjustScrollableHeight(Params.AllowAutoGrow);
         });
 
         // Init KeyEvent-Logger
@@ -471,10 +467,9 @@ Core.UI.Dialog = (function (TargetNS) {
      * @param PositionLeft The left position the dialog is positioned initially
      * @param Modal If defined and set to true, an overlay is shown for a modal dialog
      * @param Buttons The button array
-     * @param NotDraggableIE7 If true, the dialog is not draggable in IE7 (performance reasons)
      * @return nothing
      */
-    TargetNS.ShowContentDialog = function (HTML, Title, PositionTop, PositionLeft, Modal, Buttons, NotDraggableIE7) {
+    TargetNS.ShowContentDialog = function (HTML, Title, PositionTop, PositionLeft, Modal, Buttons, AllowAutoGrow) {
         TargetNS.ShowDialog({
             HTML: HTML,
             Title: Title,
@@ -484,7 +479,7 @@ Core.UI.Dialog = (function (TargetNS) {
             PositionTop: PositionTop,
             PositionLeft: PositionLeft,
             Buttons: Buttons,
-            NotDraggableIE7: NotDraggableIE7
+            AllowAutoGrow: AllowAutoGrow
         });
     };
 
@@ -515,13 +510,6 @@ Core.UI.Dialog = (function (TargetNS) {
      * @return nothing
      */
     TargetNS.CloseDialog = function (Object) {
-        function ResetRTE(Editor) {
-            CKEDITOR.instances[Editor].setMode('source');
-            window.setTimeout(function () {
-                CKEDITOR.instances[Editor].setMode('wysiwyg');
-            }, 100);
-        }
-
         var $Dialog, DialogCopy, DialogCopySelector, BackupHTML, Editor;
         $Dialog = $(Object).closest('.Dialog:visible');
 
@@ -557,23 +545,8 @@ Core.UI.Dialog = (function (TargetNS) {
             Core.Data.Set($('body'), 'DialogCopy', DialogCopy);
         }
 
-        // Repair all existing rich text editors
-        // in Firefox/Linux and IE/Win the editor is not usable anymore after a OTRS dialog was opened
-        // This workaround fixes this, because opening the wysiwyg again reloads the editor.
-        if (typeof CKEDITOR !== 'undefined') {
-            for (Editor in CKEDITOR.instances) {
-                if (typeof CKEDITOR.instances[Editor].setMode === 'function') {
-                    window.setTimeout(function () {
-                        ResetRTE(Editor);
-                    }, 0);
-                }
-            }
-        }
-
-        // Workaround for bug#6060 - In IE7, input elements can't get focus anymore after opening dialog
-        // giving focus automatically solves the problem
-        $('input:text:first').focus().blur();
-
+        // publish close event
+        Core.App.Publish('Event.UI.Dialog.CloseDialog.Close', $Dialog);
     };
 
     return TargetNS;
